@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'UIExtraDataManager.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.2)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -18,7 +18,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'UIExtraDataManager.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.9.2. It"
+#error "This file was generated using the moc from 6.10.0. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -41,6 +41,7 @@ template <> constexpr inline auto UIExtraDataManager::qt_create_metaobjectdata<q
         "UIExtraDataManager",
         "sigExtraDataMapAcknowledging",
         "",
+        "QUuid",
         "uID",
         "sigExtraDataChange",
         "strKey",
@@ -80,79 +81,79 @@ template <> constexpr inline auto UIExtraDataManager::qt_create_metaobjectdata<q
     QtMocHelpers::UintData qt_methods {
         // Signal 'sigExtraDataMapAcknowledging'
         QtMocHelpers::SignalData<void(const QUuid &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 3 },
+            { 0x80000000 | 3, 4 },
         }}),
         // Signal 'sigExtraDataChange'
-        QtMocHelpers::SignalData<void(const QUuid &, const QString &, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 3 }, { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 4 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
         }}),
         // Signal 'sigNotificationCenterAlignmentChange'
-        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigNotificationCenterOrderChange'
         QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigSettingsExpertModeChange'
+        // Signal 'sigNotificationCenterOrderChange'
         QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
+        // Signal 'sigSettingsExpertModeChange'
+        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigLanguageChange'
-        QtMocHelpers::SignalData<void(QString)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 11 },
+        QtMocHelpers::SignalData<void(QString)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 12 },
         }}),
         // Signal 'sigSelectorUIShortcutChange'
-        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigRuntimeUIShortcutChange'
         QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigRuntimeUIHostKeyCombinationChange'
+        // Signal 'sigRuntimeUIShortcutChange'
         QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
+        // Signal 'sigRuntimeUIHostKeyCombinationChange'
+        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigToolLabelsVisibilityChange'
-        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 16 },
+        QtMocHelpers::SignalData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 17 },
         }}),
         // Signal 'sigCloudProfileManagerRestrictionChange'
-        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigCloudConsoleManagerDataChange'
         QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigCloudConsoleManagerRestrictionChange'
+        // Signal 'sigCloudConsoleManagerDataChange'
         QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigDetailsCategoriesChange'
+        // Signal 'sigCloudConsoleManagerRestrictionChange'
         QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
+        // Signal 'sigDetailsCategoriesChange'
+        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigDetailsOptionsChange'
-        QtMocHelpers::SignalData<void(DetailsElementType)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 22, 23 },
+        QtMocHelpers::SignalData<void(DetailsElementType)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 23, 24 },
         }}),
         // Signal 'sigVisualStateChange'
-        QtMocHelpers::SignalData<void(const QUuid &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 25 },
+        QtMocHelpers::SignalData<void(const QUuid &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 26 },
         }}),
         // Signal 'sigMenuBarConfigurationChange'
-        QtMocHelpers::SignalData<void(const QUuid &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 25 },
+        QtMocHelpers::SignalData<void(const QUuid &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 26 },
         }}),
         // Signal 'sigStatusBarConfigurationChange'
-        QtMocHelpers::SignalData<void(const QUuid &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 25 },
+        QtMocHelpers::SignalData<void(const QUuid &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 26 },
         }}),
         // Signal 'sigHidLedsSyncStateChange'
-        QtMocHelpers::SignalData<void(bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 29 },
+        QtMocHelpers::SignalData<void(bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 30 },
         }}),
         // Signal 'sigScaleFactorChange'
-        QtMocHelpers::SignalData<void(const QUuid &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 25 },
+        QtMocHelpers::SignalData<void(const QUuid &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 26 },
         }}),
         // Signal 'sigScalingOptimizationTypeChange'
-        QtMocHelpers::SignalData<void(const QUuid &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 25 },
+        QtMocHelpers::SignalData<void(const QUuid &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 26 },
         }}),
         // Signal 'sigFontScaleFactorChanged'
-        QtMocHelpers::SignalData<void(int)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Int, 33 },
+        QtMocHelpers::SignalData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Int, 34 },
         }}),
         // Signal 'sigDisableHostScreenSaverStateChange'
-        QtMocHelpers::SignalData<void(bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 35 },
+        QtMocHelpers::SignalData<void(bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 36 },
         }}),
         // Slot 'sltExtraDataChange'
-        QtMocHelpers::SlotData<void(const QUuid &, const QString &, const QString &)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QUuid, 25 }, { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
+        QtMocHelpers::SlotData<void(const QUuid &, const QString &, const QString &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 3, 26 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
         }}),
     };
     QtMocHelpers::UintData qt_properties {
@@ -177,30 +178,30 @@ void UIExtraDataManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, i
     auto *_t = static_cast<UIExtraDataManager *>(_o);
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
-        case 0: _t->sigExtraDataMapAcknowledging((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 1: _t->sigExtraDataChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[3]))); break;
+        case 0: _t->sigExtraDataMapAcknowledging((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 1: _t->sigExtraDataChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
         case 2: _t->sigNotificationCenterAlignmentChange(); break;
         case 3: _t->sigNotificationCenterOrderChange(); break;
         case 4: _t->sigSettingsExpertModeChange(); break;
-        case 5: _t->sigLanguageChange((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
+        case 5: _t->sigLanguageChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
         case 6: _t->sigSelectorUIShortcutChange(); break;
         case 7: _t->sigRuntimeUIShortcutChange(); break;
         case 8: _t->sigRuntimeUIHostKeyCombinationChange(); break;
-        case 9: _t->sigToolLabelsVisibilityChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 9: _t->sigToolLabelsVisibilityChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 10: _t->sigCloudProfileManagerRestrictionChange(); break;
         case 11: _t->sigCloudConsoleManagerDataChange(); break;
         case 12: _t->sigCloudConsoleManagerRestrictionChange(); break;
         case 13: _t->sigDetailsCategoriesChange(); break;
-        case 14: _t->sigDetailsOptionsChange((*reinterpret_cast< std::add_pointer_t<DetailsElementType>>(_a[1]))); break;
-        case 15: _t->sigVisualStateChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 16: _t->sigMenuBarConfigurationChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 17: _t->sigStatusBarConfigurationChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 18: _t->sigHidLedsSyncStateChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 19: _t->sigScaleFactorChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 20: _t->sigScalingOptimizationTypeChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 21: _t->sigFontScaleFactorChanged((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
-        case 22: _t->sigDisableHostScreenSaverStateChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 23: _t->sltExtraDataChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[3]))); break;
+        case 14: _t->sigDetailsOptionsChange((*reinterpret_cast<std::add_pointer_t<DetailsElementType>>(_a[1]))); break;
+        case 15: _t->sigVisualStateChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 16: _t->sigMenuBarConfigurationChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 17: _t->sigStatusBarConfigurationChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 18: _t->sigHidLedsSyncStateChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 19: _t->sigScaleFactorChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 20: _t->sigScalingOptimizationTypeChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 21: _t->sigFontScaleFactorChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
+        case 22: _t->sigDisableHostScreenSaverStateChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 23: _t->sltExtraDataChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
         default: ;
         }
     }
