@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'UIFileManagerTable.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.2)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -18,7 +18,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'UIFileManagerTable.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.9.2. It"
+#error "This file was generated using the moc from 6.10.0. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -72,7 +72,7 @@ void UIDirectoryDiskUsageComputer::qt_static_metacall(QObject *_o, QMetaObject::
     auto *_t = static_cast<UIDirectoryDiskUsageComputer *>(_o);
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
-        case 0: _t->sigResultUpdated((*reinterpret_cast< std::add_pointer_t<UIDirectoryStatistics>>(_a[1]))); break;
+        case 0: _t->sigResultUpdated((*reinterpret_cast<std::add_pointer_t<UIDirectoryStatistics>>(_a[1]))); break;
         default: ;
         }
     }
@@ -230,6 +230,7 @@ template <> constexpr inline auto UIFileManagerTable::qt_create_metaobjectdata<q
         "sltInvertSelection",
         "sltRetranslateUI",
         "sltCreateFileViewContextMenu",
+        "QPoint",
         "point",
         "sltSelectionChanged",
         "QItemSelection",
@@ -307,26 +308,26 @@ template <> constexpr inline auto UIFileManagerTable::qt_create_metaobjectdata<q
         QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessProtected, QMetaType::Void),
         // Slot 'sltCreateFileViewContextMenu'
         QtMocHelpers::SlotData<void(const QPoint &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QPoint, 35 },
+            { 0x80000000 | 35, 36 },
         }}),
         // Slot 'sltSelectionChanged'
-        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 37, 38 }, { 0x80000000 | 37, 39 },
+        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 38, 39 }, { 0x80000000 | 38, 40 },
         }}),
         // Slot 'sltSearchTextChanged'
-        QtMocHelpers::SlotData<void(const QString &)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QString, 41 },
+        QtMocHelpers::SlotData<void(const QString &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::QString, 42 },
         }}),
         // Slot 'sltHandleItemRenameAttempt'
-        QtMocHelpers::SlotData<void(UIFileSystemItem *, const QString &, const QString &, const QString &)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 43, 44 }, { QMetaType::QString, 45 }, { QMetaType::QString, 46 }, { QMetaType::QString, 47 },
+        QtMocHelpers::SlotData<void(UIFileSystemItem *, const QString &, const QString &, const QString &)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 44, 45 }, { QMetaType::QString, 46 }, { QMetaType::QString, 47 }, { QMetaType::QString, 48 },
         }}),
         // Slot 'sltHandleNavigationWidgetPathChange'
-        QtMocHelpers::SlotData<void(const QString &)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QString, 49 },
+        QtMocHelpers::SlotData<void(const QString &)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::QString, 50 },
         }}),
         // Slot 'sltHandleNavigationWidgetHistoryListChanged'
-        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
     };
     QtMocHelpers::UintData qt_properties {
     };
@@ -350,14 +351,14 @@ void UIFileManagerTable::qt_static_metacall(QObject *_o, QMetaObject::Call _c, i
     auto *_t = static_cast<UIFileManagerTable *>(_o);
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
-        case 0: _t->sigLogOutput((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<FileManagerLogType>>(_a[3]))); break;
+        case 0: _t->sigLogOutput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<FileManagerLogType>>(_a[3]))); break;
         case 1: _t->sigDeleteConfirmationOptionChanged(); break;
-        case 2: _t->sigSelectionChanged((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 2: _t->sigSelectionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 3: _t->sigAltDoubleClick(); break;
-        case 4: _t->sltReceiveDirectoryStatistics((*reinterpret_cast< std::add_pointer_t<UIDirectoryStatistics>>(_a[1]))); break;
+        case 4: _t->sltReceiveDirectoryStatistics((*reinterpret_cast<std::add_pointer_t<UIDirectoryStatistics>>(_a[1]))); break;
         case 5: _t->sltCreateNewDirectory(); break;
-        case 6: _t->sltItemDoubleClicked((*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[1]))); break;
-        case 7: _t->sltItemClicked((*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[1]))); break;
+        case 6: _t->sltItemDoubleClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
+        case 7: _t->sltItemClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
         case 8: _t->sltAltDoubleClick(); break;
         case 9: _t->sltGoUp(); break;
         case 10: _t->sltGoHome(); break;
@@ -373,11 +374,11 @@ void UIFileManagerTable::qt_static_metacall(QObject *_o, QMetaObject::Call _c, i
         case 20: _t->sltSelectAll(); break;
         case 21: _t->sltInvertSelection(); break;
         case 22: _t->sltRetranslateUI(); break;
-        case 23: _t->sltCreateFileViewContextMenu((*reinterpret_cast< std::add_pointer_t<QPoint>>(_a[1]))); break;
-        case 24: _t->sltSelectionChanged((*reinterpret_cast< std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QItemSelection>>(_a[2]))); break;
-        case 25: _t->sltSearchTextChanged((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 26: _t->sltHandleItemRenameAttempt((*reinterpret_cast< std::add_pointer_t<UIFileSystemItem*>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[4]))); break;
-        case 27: _t->sltHandleNavigationWidgetPathChange((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
+        case 23: _t->sltCreateFileViewContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
+        case 24: _t->sltSelectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
+        case 25: _t->sltSearchTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 26: _t->sltHandleItemRenameAttempt((*reinterpret_cast<std::add_pointer_t<UIFileSystemItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
+        case 27: _t->sltHandleNavigationWidgetPathChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
         case 28: _t->sltHandleNavigationWidgetHistoryListChanged(); break;
         default: ;
         }
