@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'UIMainEventListener.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.2)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -18,7 +18,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'UIMainEventListener.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.9.2. It"
+#error "This file was generated using the moc from 6.10.0. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -44,6 +44,7 @@ template <> constexpr inline auto UIMainEventListener::qt_create_metaobjectdata<
         "sigVBoxSVCAvailabilityChange",
         "fAvailable",
         "sigMachineStateChange",
+        "QUuid",
         "uId",
         "KMachineState",
         "state",
@@ -127,6 +128,7 @@ template <> constexpr inline auto UIMainEventListener::qt_create_metaobjectdata<
         "KGuestMonitorChangedEventType",
         "changeType",
         "uScreenId",
+        "QRect",
         "screenGeo",
         "sigRuntimeError",
         "fFatal",
@@ -175,196 +177,196 @@ template <> constexpr inline auto UIMainEventListener::qt_create_metaobjectdata<
         }}),
         // Signal 'sigMachineStateChange'
         QtMocHelpers::SignalData<void(const QUuid &, const KMachineState)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 6 }, { 0x80000000 | 7, 8 },
+            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
         }}),
         // Signal 'sigMachineDataChange'
-        QtMocHelpers::SignalData<void(const QUuid &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 6 },
+        QtMocHelpers::SignalData<void(const QUuid &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 7 },
         }}),
         // Signal 'sigMachineRegistered'
-        QtMocHelpers::SignalData<void(const QUuid &, const bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 6 }, { QMetaType::Bool, 11 },
+        QtMocHelpers::SignalData<void(const QUuid &, const bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 7 }, { QMetaType::Bool, 12 },
         }}),
         // Signal 'sigMachineGroupsChange'
-        QtMocHelpers::SignalData<void(const QUuid &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 6 },
+        QtMocHelpers::SignalData<void(const QUuid &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 7 },
         }}),
         // Signal 'sigSessionStateChange'
-        QtMocHelpers::SignalData<void(const QUuid &, const KSessionState)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 6 }, { 0x80000000 | 14, 8 },
+        QtMocHelpers::SignalData<void(const QUuid &, const KSessionState)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 7 }, { 0x80000000 | 15, 9 },
         }}),
         // Signal 'sigSnapshotTake'
-        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 6 }, { QMetaType::QUuid, 16 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 17 },
         }}),
         // Signal 'sigSnapshotDelete'
-        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 6 }, { QMetaType::QUuid, 16 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 17 },
         }}),
         // Signal 'sigSnapshotChange'
-        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 6 }, { QMetaType::QUuid, 16 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 17 },
         }}),
         // Signal 'sigSnapshotRestore'
-        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 6 }, { QMetaType::QUuid, 16 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 17 },
         }}),
         // Signal 'sigCloudProviderUninstall'
-        QtMocHelpers::SignalData<void(const QUuid &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 6 },
+        QtMocHelpers::SignalData<void(const QUuid &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 7 },
         }}),
         // Signal 'sigCloudProviderListChanged'
-        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigCloudProfileRegistered'
-        QtMocHelpers::SignalData<void(const QUuid &, const QString &, bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 23 }, { QMetaType::QString, 24 }, { QMetaType::Bool, 11 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QString &, bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 24 }, { QMetaType::QString, 25 }, { QMetaType::Bool, 12 },
         }}),
         // Signal 'sigCloudProfileChanged'
-        QtMocHelpers::SignalData<void(const QUuid &, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 23 }, { QMetaType::QString, 24 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 24 }, { QMetaType::QString, 25 },
         }}),
         // Signal 'sigExtensionPackInstalled'
-        QtMocHelpers::SignalData<void(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 24 },
+        QtMocHelpers::SignalData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 25 },
         }}),
         // Signal 'sigExtensionPackUninstalled'
-        QtMocHelpers::SignalData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 24 },
+        QtMocHelpers::SignalData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 25 },
         }}),
         // Signal 'sigExtraDataCanChange'
-        QtMocHelpers::SignalData<void(const QUuid &, const QString &, const QString &, bool &, QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 6 }, { QMetaType::QString, 29 }, { QMetaType::QString, 30 }, { 0x80000000 | 31, 32 },
-            { 0x80000000 | 33, 34 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QString &, const QString &, bool &, QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 7 }, { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { 0x80000000 | 32, 33 },
+            { 0x80000000 | 34, 35 },
         }}),
         // Signal 'sigExtraDataChange'
-        QtMocHelpers::SignalData<void(const QUuid &, const QString &, const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 6 }, { QMetaType::QString, 29 }, { QMetaType::QString, 30 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QString &, const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 7 }, { QMetaType::QString, 30 }, { QMetaType::QString, 31 },
         }}),
         // Signal 'sigStorageControllerChange'
-        QtMocHelpers::SignalData<void(const QUuid &, const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 37 }, { QMetaType::QString, 38 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 38 }, { QMetaType::QString, 39 },
         }}),
         // Signal 'sigStorageDeviceChange'
-        QtMocHelpers::SignalData<void(CMediumAttachment, bool, bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 40, 41 }, { QMetaType::Bool, 42 }, { QMetaType::Bool, 43 },
+        QtMocHelpers::SignalData<void(CMediumAttachment, bool, bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 41, 42 }, { QMetaType::Bool, 43 }, { QMetaType::Bool, 44 },
         }}),
         // Signal 'sigMediumChange'
-        QtMocHelpers::SignalData<void(CMediumAttachment)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 40, 41 },
+        QtMocHelpers::SignalData<void(CMediumAttachment)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 41, 42 },
         }}),
         // Signal 'sigMediumConfigChange'
-        QtMocHelpers::SignalData<void(CMedium)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 46, 47 },
+        QtMocHelpers::SignalData<void(CMedium)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 47, 48 },
         }}),
         // Signal 'sigMediumRegistered'
-        QtMocHelpers::SignalData<void(const QUuid &, KDeviceType, bool)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 49 }, { 0x80000000 | 50, 51 }, { QMetaType::Bool, 11 },
+        QtMocHelpers::SignalData<void(const QUuid &, KDeviceType, bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 50 }, { 0x80000000 | 51, 52 }, { QMetaType::Bool, 12 },
         }}),
         // Signal 'sigMousePointerShapeChange'
-        QtMocHelpers::SignalData<void(const UIMousePointerShapeData &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 53, 54 },
+        QtMocHelpers::SignalData<void(const UIMousePointerShapeData &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 54, 55 },
         }}),
         // Signal 'sigMouseCapabilityChange'
-        QtMocHelpers::SignalData<void(bool, bool, bool, bool, bool)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 56 }, { QMetaType::Bool, 57 }, { QMetaType::Bool, 58 }, { QMetaType::Bool, 59 },
-            { QMetaType::Bool, 60 },
+        QtMocHelpers::SignalData<void(bool, bool, bool, bool, bool)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 57 }, { QMetaType::Bool, 58 }, { QMetaType::Bool, 59 }, { QMetaType::Bool, 60 },
+            { QMetaType::Bool, 61 },
         }}),
         // Signal 'sigCursorPositionChange'
-        QtMocHelpers::SignalData<void(bool, unsigned long, unsigned long)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 62 }, { QMetaType::ULong, 63 }, { QMetaType::ULong, 64 },
+        QtMocHelpers::SignalData<void(bool, unsigned long, unsigned long)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 63 }, { QMetaType::ULong, 64 }, { QMetaType::ULong, 65 },
         }}),
         // Signal 'sigKeyboardLedsChange'
-        QtMocHelpers::SignalData<void(bool, bool, bool)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 66 }, { QMetaType::Bool, 67 }, { QMetaType::Bool, 68 },
+        QtMocHelpers::SignalData<void(bool, bool, bool)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 67 }, { QMetaType::Bool, 68 }, { QMetaType::Bool, 69 },
         }}),
         // Signal 'sigStateChange'
-        QtMocHelpers::SignalData<void(KMachineState)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 7, 8 },
+        QtMocHelpers::SignalData<void(KMachineState)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 8, 9 },
         }}),
         // Signal 'sigAdditionsChange'
-        QtMocHelpers::SignalData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SignalData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigNetworkAdapterChange'
-        QtMocHelpers::SignalData<void(CNetworkAdapter)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 72, 73 },
+        QtMocHelpers::SignalData<void(CNetworkAdapter)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 73, 74 },
         }}),
         // Signal 'sigVRDEChange'
-        QtMocHelpers::SignalData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigRecordingChange'
         QtMocHelpers::SignalData<void()>(75, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigUSBControllerChange'
+        // Signal 'sigRecordingChange'
         QtMocHelpers::SignalData<void()>(76, 2, QMC::AccessPublic, QMetaType::Void),
+        // Signal 'sigUSBControllerChange'
+        QtMocHelpers::SignalData<void()>(77, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigUSBDeviceStateChange'
-        QtMocHelpers::SignalData<void(CUSBDevice, bool, CVirtualBoxErrorInfo)>(77, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 78, 79 }, { QMetaType::Bool, 80 }, { 0x80000000 | 81, 82 },
+        QtMocHelpers::SignalData<void(CUSBDevice, bool, CVirtualBoxErrorInfo)>(78, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 79, 80 }, { QMetaType::Bool, 81 }, { 0x80000000 | 82, 83 },
         }}),
         // Signal 'sigSharedFolderChange'
-        QtMocHelpers::SignalData<void()>(83, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigCPUExecutionCapChange'
         QtMocHelpers::SignalData<void()>(84, 2, QMC::AccessPublic, QMetaType::Void),
+        // Signal 'sigCPUExecutionCapChange'
+        QtMocHelpers::SignalData<void()>(85, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigGuestMonitorChange'
-        QtMocHelpers::SignalData<void(KGuestMonitorChangedEventType, ulong, QRect)>(85, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 86, 87 }, { QMetaType::ULong, 88 }, { QMetaType::QRect, 89 },
+        QtMocHelpers::SignalData<void(KGuestMonitorChangedEventType, ulong, QRect)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 87, 88 }, { QMetaType::ULong, 89 }, { 0x80000000 | 90, 91 },
         }}),
         // Signal 'sigRuntimeError'
-        QtMocHelpers::SignalData<void(bool, QString, QString)>(90, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 91 }, { QMetaType::QString, 92 }, { QMetaType::QString, 93 },
+        QtMocHelpers::SignalData<void(bool, QString, QString)>(92, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 93 }, { QMetaType::QString, 94 }, { QMetaType::QString, 95 },
         }}),
         // Signal 'sigCanShowWindow'
-        QtMocHelpers::SignalData<void(bool &, QString &)>(94, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 31, 32 }, { 0x80000000 | 33, 95 },
+        QtMocHelpers::SignalData<void(bool &, QString &)>(96, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 32, 33 }, { 0x80000000 | 34, 97 },
         }}),
         // Signal 'sigShowWindow'
-        QtMocHelpers::SignalData<void(qint64 &)>(96, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 97, 98 },
+        QtMocHelpers::SignalData<void(qint64 &)>(98, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 99, 100 },
         }}),
         // Signal 'sigAudioAdapterChange'
-        QtMocHelpers::SignalData<void()>(99, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SignalData<void()>(101, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigClipboardModeChange'
-        QtMocHelpers::SignalData<void(KClipboardMode)>(100, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 101, 102 },
+        QtMocHelpers::SignalData<void(KClipboardMode)>(102, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 103, 104 },
         }}),
         // Signal 'sigClipboardError'
-        QtMocHelpers::SignalData<void(const QString &)>(103, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 104 },
+        QtMocHelpers::SignalData<void(const QString &)>(105, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 106 },
         }}),
         // Signal 'sigDnDModeChange'
-        QtMocHelpers::SignalData<void(KDnDMode)>(105, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 106, 107 },
+        QtMocHelpers::SignalData<void(KDnDMode)>(107, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 108, 109 },
         }}),
         // Signal 'sigProgressPercentageChange'
-        QtMocHelpers::SignalData<void(const QUuid &, const int)>(108, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 109 }, { QMetaType::Int, 110 },
+        QtMocHelpers::SignalData<void(const QUuid &, const int)>(110, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 111 }, { QMetaType::Int, 112 },
         }}),
         // Signal 'sigProgressTaskComplete'
-        QtMocHelpers::SignalData<void(const QUuid &)>(111, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 109 },
+        QtMocHelpers::SignalData<void(const QUuid &)>(113, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 6, 111 },
         }}),
         // Signal 'sigGuestSessionRegistered'
-        QtMocHelpers::SignalData<void(CGuestSession)>(112, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 113, 114 },
+        QtMocHelpers::SignalData<void(CGuestSession)>(114, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 115, 116 },
         }}),
         // Signal 'sigGuestSessionUnregistered'
-        QtMocHelpers::SignalData<void(CGuestSession)>(115, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 113, 114 },
+        QtMocHelpers::SignalData<void(CGuestSession)>(117, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 115, 116 },
         }}),
         // Signal 'sigGuestProcessRegistered'
-        QtMocHelpers::SignalData<void(CGuestProcess)>(116, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 117, 118 },
+        QtMocHelpers::SignalData<void(CGuestProcess)>(118, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 119, 120 },
         }}),
         // Signal 'sigGuestProcessUnregistered'
-        QtMocHelpers::SignalData<void(CGuestProcess)>(119, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 117, 118 },
+        QtMocHelpers::SignalData<void(CGuestProcess)>(121, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 119, 120 },
         }}),
         // Signal 'sigGuestSessionStatedChanged'
-        QtMocHelpers::SignalData<void(const CGuestSessionStateChangedEvent &)>(120, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 121, 122 },
+        QtMocHelpers::SignalData<void(const CGuestSessionStateChangedEvent &)>(122, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 123, 124 },
         }}),
         // Signal 'sigGuestProcessStateChanged'
-        QtMocHelpers::SignalData<void(const CGuestProcessStateChangedEvent &)>(123, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 124, 122 },
+        QtMocHelpers::SignalData<void(const CGuestProcessStateChangedEvent &)>(125, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 126, 124 },
         }}),
         // Slot 'sltHandleThreadFinished'
-        QtMocHelpers::SlotData<void()>(125, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(127, 2, QMC::AccessPrivate, QMetaType::Void),
     };
     QtMocHelpers::UintData qt_properties {
     };
@@ -389,58 +391,58 @@ void UIMainEventListener::qt_static_metacall(QObject *_o, QMetaObject::Call _c,
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
         case 0: _t->sigListeningFinished(); break;
-        case 1: _t->sigVBoxSVCAvailabilityChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 2: _t->sigMachineStateChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<KMachineState>>(_a[2]))); break;
-        case 3: _t->sigMachineDataChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 4: _t->sigMachineRegistered((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2]))); break;
-        case 5: _t->sigMachineGroupsChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 6: _t->sigSessionStateChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<KSessionState>>(_a[2]))); break;
-        case 7: _t->sigSnapshotTake((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[2]))); break;
-        case 8: _t->sigSnapshotDelete((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[2]))); break;
-        case 9: _t->sigSnapshotChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[2]))); break;
-        case 10: _t->sigSnapshotRestore((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[2]))); break;
-        case 11: _t->sigCloudProviderUninstall((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 1: _t->sigVBoxSVCAvailabilityChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 2: _t->sigMachineStateChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMachineState>>(_a[2]))); break;
+        case 3: _t->sigMachineDataChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 4: _t->sigMachineRegistered((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
+        case 5: _t->sigMachineGroupsChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 6: _t->sigSessionStateChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KSessionState>>(_a[2]))); break;
+        case 7: _t->sigSnapshotTake((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
+        case 8: _t->sigSnapshotDelete((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
+        case 9: _t->sigSnapshotChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
+        case 10: _t->sigSnapshotRestore((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
+        case 11: _t->sigCloudProviderUninstall((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
         case 12: _t->sigCloudProviderListChanged(); break;
-        case 13: _t->sigCloudProfileRegistered((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
-        case 14: _t->sigCloudProfileChanged((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2]))); break;
-        case 15: _t->sigExtensionPackInstalled((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 16: _t->sigExtensionPackUninstalled((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 17: _t->sigExtraDataCanChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast< std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast< std::add_pointer_t<QString&>>(_a[5]))); break;
-        case 18: _t->sigExtraDataChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[3]))); break;
-        case 19: _t->sigStorageControllerChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2]))); break;
-        case 20: _t->sigStorageDeviceChange((*reinterpret_cast< std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
-        case 21: _t->sigMediumChange((*reinterpret_cast< std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
-        case 22: _t->sigMediumConfigChange((*reinterpret_cast< std::add_pointer_t<CMedium>>(_a[1]))); break;
-        case 23: _t->sigMediumRegistered((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<KDeviceType>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
-        case 24: _t->sigMousePointerShapeChange((*reinterpret_cast< std::add_pointer_t<UIMousePointerShapeData>>(_a[1]))); break;
-        case 25: _t->sigMouseCapabilityChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[5]))); break;
-        case 26: _t->sigCursorPositionChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[3]))); break;
-        case 27: _t->sigKeyboardLedsChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
-        case 28: _t->sigStateChange((*reinterpret_cast< std::add_pointer_t<KMachineState>>(_a[1]))); break;
+        case 13: _t->sigCloudProfileRegistered((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 14: _t->sigCloudProfileChanged((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
+        case 15: _t->sigExtensionPackInstalled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 16: _t->sigExtensionPackUninstalled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 17: _t->sigExtraDataCanChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[5]))); break;
+        case 18: _t->sigExtraDataChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
+        case 19: _t->sigStorageControllerChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
+        case 20: _t->sigStorageDeviceChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 21: _t->sigMediumChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
+        case 22: _t->sigMediumConfigChange((*reinterpret_cast<std::add_pointer_t<CMedium>>(_a[1]))); break;
+        case 23: _t->sigMediumRegistered((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KDeviceType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 24: _t->sigMousePointerShapeChange((*reinterpret_cast<std::add_pointer_t<UIMousePointerShapeData>>(_a[1]))); break;
+        case 25: _t->sigMouseCapabilityChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
+        case 26: _t->sigCursorPositionChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[3]))); break;
+        case 27: _t->sigKeyboardLedsChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 28: _t->sigStateChange((*reinterpret_cast<std::add_pointer_t<KMachineState>>(_a[1]))); break;
         case 29: _t->sigAdditionsChange(); break;
-        case 30: _t->sigNetworkAdapterChange((*reinterpret_cast< std::add_pointer_t<CNetworkAdapter>>(_a[1]))); break;
+        case 30: _t->sigNetworkAdapterChange((*reinterpret_cast<std::add_pointer_t<CNetworkAdapter>>(_a[1]))); break;
         case 31: _t->sigVRDEChange(); break;
         case 32: _t->sigRecordingChange(); break;
         case 33: _t->sigUSBControllerChange(); break;
-        case 34: _t->sigUSBDeviceStateChange((*reinterpret_cast< std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
+        case 34: _t->sigUSBDeviceStateChange((*reinterpret_cast<std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
         case 35: _t->sigSharedFolderChange(); break;
         case 36: _t->sigCPUExecutionCapChange(); break;
-        case 37: _t->sigGuestMonitorChange((*reinterpret_cast< std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QRect>>(_a[3]))); break;
-        case 38: _t->sigRuntimeError((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[3]))); break;
-        case 39: _t->sigCanShowWindow((*reinterpret_cast< std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString&>>(_a[2]))); break;
-        case 40: _t->sigShowWindow((*reinterpret_cast< std::add_pointer_t<qint64&>>(_a[1]))); break;
+        case 37: _t->sigGuestMonitorChange((*reinterpret_cast<std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3]))); break;
+        case 38: _t->sigRuntimeError((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
+        case 39: _t->sigCanShowWindow((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2]))); break;
+        case 40: _t->sigShowWindow((*reinterpret_cast<std::add_pointer_t<qint64&>>(_a[1]))); break;
         case 41: _t->sigAudioAdapterChange(); break;
-        case 42: _t->sigClipboardModeChange((*reinterpret_cast< std::add_pointer_t<KClipboardMode>>(_a[1]))); break;
-        case 43: _t->sigClipboardError((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 44: _t->sigDnDModeChange((*reinterpret_cast< std::add_pointer_t<KDnDMode>>(_a[1]))); break;
-        case 45: _t->sigProgressPercentageChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<int>>(_a[2]))); break;
-        case 46: _t->sigProgressTaskComplete((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 47: _t->sigGuestSessionRegistered((*reinterpret_cast< std::add_pointer_t<CGuestSession>>(_a[1]))); break;
-        case 48: _t->sigGuestSessionUnregistered((*reinterpret_cast< std::add_pointer_t<CGuestSession>>(_a[1]))); break;
-        case 49: _t->sigGuestProcessRegistered((*reinterpret_cast< std::add_pointer_t<CGuestProcess>>(_a[1]))); break;
-        case 50: _t->sigGuestProcessUnregistered((*reinterpret_cast< std::add_pointer_t<CGuestProcess>>(_a[1]))); break;
-        case 51: _t->sigGuestSessionStatedChanged((*reinterpret_cast< std::add_pointer_t<CGuestSessionStateChangedEvent>>(_a[1]))); break;
-        case 52: _t->sigGuestProcessStateChanged((*reinterpret_cast< std::add_pointer_t<CGuestProcessStateChangedEvent>>(_a[1]))); break;
+        case 42: _t->sigClipboardModeChange((*reinterpret_cast<std::add_pointer_t<KClipboardMode>>(_a[1]))); break;
+        case 43: _t->sigClipboardError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 44: _t->sigDnDModeChange((*reinterpret_cast<std::add_pointer_t<KDnDMode>>(_a[1]))); break;
+        case 45: _t->sigProgressPercentageChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
+        case 46: _t->sigProgressTaskComplete((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 47: _t->sigGuestSessionRegistered((*reinterpret_cast<std::add_pointer_t<CGuestSession>>(_a[1]))); break;
+        case 48: _t->sigGuestSessionUnregistered((*reinterpret_cast<std::add_pointer_t<CGuestSession>>(_a[1]))); break;
+        case 49: _t->sigGuestProcessRegistered((*reinterpret_cast<std::add_pointer_t<CGuestProcess>>(_a[1]))); break;
+        case 50: _t->sigGuestProcessUnregistered((*reinterpret_cast<std::add_pointer_t<CGuestProcess>>(_a[1]))); break;
+        case 51: _t->sigGuestSessionStatedChanged((*reinterpret_cast<std::add_pointer_t<CGuestSessionStateChangedEvent>>(_a[1]))); break;
+        case 52: _t->sigGuestProcessStateChanged((*reinterpret_cast<std::add_pointer_t<CGuestProcessStateChangedEvent>>(_a[1]))); break;
         case 53: _t->sltHandleThreadFinished(); break;
         default: ;
         }
