@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'UIVirtualBoxEventHandler.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.2)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -18,7 +18,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'UIVirtualBoxEventHandler.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.9.2. It"
+#error "This file was generated using the moc from 6.10.0. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -41,6 +41,7 @@ template <> constexpr inline auto UIVirtualBoxEventHandler::qt_create_metaobject
         "UIVirtualBoxEventHandler",
         "sigMachineStateChange",
         "",
+        "QUuid",
         "uId",
         "KMachineState",
         "state",
@@ -84,81 +85,81 @@ template <> constexpr inline auto UIVirtualBoxEventHandler::qt_create_metaobject
     QtMocHelpers::UintData qt_methods {
         // Signal 'sigMachineStateChange'
         QtMocHelpers::SignalData<void(const QUuid &, const KMachineState)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 3 }, { 0x80000000 | 4, 5 },
+            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
         }}),
         // Signal 'sigMachineDataChange'
-        QtMocHelpers::SignalData<void(const QUuid &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 3 },
+        QtMocHelpers::SignalData<void(const QUuid &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 4 },
         }}),
         // Signal 'sigMachineRegistered'
-        QtMocHelpers::SignalData<void(const QUuid &, const bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 3 }, { QMetaType::Bool, 8 },
+        QtMocHelpers::SignalData<void(const QUuid &, const bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 9 },
         }}),
         // Signal 'sigMachineGroupsChange'
-        QtMocHelpers::SignalData<void(const QUuid &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 3 },
+        QtMocHelpers::SignalData<void(const QUuid &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 4 },
         }}),
         // Signal 'sigSessionStateChange'
-        QtMocHelpers::SignalData<void(const QUuid &, const KSessionState)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 3 }, { 0x80000000 | 11, 5 },
+        QtMocHelpers::SignalData<void(const QUuid &, const KSessionState)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 4 }, { 0x80000000 | 12, 6 },
         }}),
         // Signal 'sigSnapshotTake'
-        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 3 }, { QMetaType::QUuid, 13 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 14 },
         }}),
         // Signal 'sigSnapshotDelete'
-        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 3 }, { QMetaType::QUuid, 13 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 14 },
         }}),
         // Signal 'sigSnapshotChange'
-        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 3 }, { QMetaType::QUuid, 13 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 14 },
         }}),
         // Signal 'sigSnapshotRestore'
-        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 3 }, { QMetaType::QUuid, 13 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 14 },
         }}),
         // Signal 'sigCloudProviderUninstall'
-        QtMocHelpers::SignalData<void(const QUuid &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 3 },
+        QtMocHelpers::SignalData<void(const QUuid &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 4 },
         }}),
         // Signal 'sigCloudProviderListChanged'
-        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigCloudProfileRegistered'
-        QtMocHelpers::SignalData<void(const QUuid &, const QString &, bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 20 }, { QMetaType::QString, 21 }, { QMetaType::Bool, 8 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QString &, bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 21 }, { QMetaType::QString, 22 }, { QMetaType::Bool, 9 },
         }}),
         // Signal 'sigCloudProfileChanged'
-        QtMocHelpers::SignalData<void(const QUuid &, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 20 }, { QMetaType::QString, 21 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 21 }, { QMetaType::QString, 22 },
         }}),
         // Signal 'sigStorageControllerChange'
-        QtMocHelpers::SignalData<void(const QUuid &, const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 24 }, { QMetaType::QString, 25 },
+        QtMocHelpers::SignalData<void(const QUuid &, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 25 }, { QMetaType::QString, 26 },
         }}),
         // Signal 'sigStorageDeviceChange'
-        QtMocHelpers::SignalData<void(CMediumAttachment, bool, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 27, 28 }, { QMetaType::Bool, 29 }, { QMetaType::Bool, 30 },
+        QtMocHelpers::SignalData<void(CMediumAttachment, bool, bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 28, 29 }, { QMetaType::Bool, 30 }, { QMetaType::Bool, 31 },
         }}),
         // Signal 'sigMediumChange'
-        QtMocHelpers::SignalData<void(CMediumAttachment)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 27, 28 },
+        QtMocHelpers::SignalData<void(CMediumAttachment)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 28, 29 },
         }}),
         // Signal 'sigMediumConfigChange'
-        QtMocHelpers::SignalData<void(CMedium)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 33, 34 },
+        QtMocHelpers::SignalData<void(CMedium)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 34, 35 },
         }}),
         // Signal 'sigMediumRegistered'
-        QtMocHelpers::SignalData<void(const QUuid &, KDeviceType, bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 36 }, { 0x80000000 | 37, 38 }, { QMetaType::Bool, 8 },
+        QtMocHelpers::SignalData<void(const QUuid &, KDeviceType, bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 3, 37 }, { 0x80000000 | 38, 39 }, { QMetaType::Bool, 9 },
         }}),
         // Signal 'sigExtensionPackInstalled'
-        QtMocHelpers::SignalData<void(const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 21 },
+        QtMocHelpers::SignalData<void(const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 22 },
         }}),
         // Signal 'sigExtensionPackUninstalled'
-        QtMocHelpers::SignalData<void(const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 21 },
+        QtMocHelpers::SignalData<void(const QString &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 22 },
         }}),
     };
     QtMocHelpers::UintData qt_properties {
@@ -183,26 +184,26 @@ void UIVirtualBoxEventHandler::qt_static_metacall(QObject *_o, QMetaObject::Call
     auto *_t = static_cast<UIVirtualBoxEventHandler *>(_o);
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
-        case 0: _t->sigMachineStateChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<KMachineState>>(_a[2]))); break;
-        case 1: _t->sigMachineDataChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 2: _t->sigMachineRegistered((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2]))); break;
-        case 3: _t->sigMachineGroupsChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 4: _t->sigSessionStateChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<KSessionState>>(_a[2]))); break;
-        case 5: _t->sigSnapshotTake((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[2]))); break;
-        case 6: _t->sigSnapshotDelete((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[2]))); break;
-        case 7: _t->sigSnapshotChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[2]))); break;
-        case 8: _t->sigSnapshotRestore((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[2]))); break;
-        case 9: _t->sigCloudProviderUninstall((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 0: _t->sigMachineStateChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMachineState>>(_a[2]))); break;
+        case 1: _t->sigMachineDataChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 2: _t->sigMachineRegistered((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
+        case 3: _t->sigMachineGroupsChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 4: _t->sigSessionStateChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KSessionState>>(_a[2]))); break;
+        case 5: _t->sigSnapshotTake((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
+        case 6: _t->sigSnapshotDelete((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
+        case 7: _t->sigSnapshotChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
+        case 8: _t->sigSnapshotRestore((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
+        case 9: _t->sigCloudProviderUninstall((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
         case 10: _t->sigCloudProviderListChanged(); break;
-        case 11: _t->sigCloudProfileRegistered((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
-        case 12: _t->sigCloudProfileChanged((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2]))); break;
-        case 13: _t->sigStorageControllerChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2]))); break;
-        case 14: _t->sigStorageDeviceChange((*reinterpret_cast< std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
-        case 15: _t->sigMediumChange((*reinterpret_cast< std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
-        case 16: _t->sigMediumConfigChange((*reinterpret_cast< std::add_pointer_t<CMedium>>(_a[1]))); break;
-        case 17: _t->sigMediumRegistered((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<KDeviceType>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
-        case 18: _t->sigExtensionPackInstalled((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 19: _t->sigExtensionPackUninstalled((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
+        case 11: _t->sigCloudProfileRegistered((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 12: _t->sigCloudProfileChanged((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
+        case 13: _t->sigStorageControllerChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
+        case 14: _t->sigStorageDeviceChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 15: _t->sigMediumChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
+        case 16: _t->sigMediumConfigChange((*reinterpret_cast<std::add_pointer_t<CMedium>>(_a[1]))); break;
+        case 17: _t->sigMediumRegistered((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KDeviceType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 18: _t->sigExtensionPackInstalled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 19: _t->sigExtensionPackUninstalled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
         default: ;
         }
     }
