@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'UIMediumManager.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.2)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -18,7 +18,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'UIMediumManager.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.9.2. It"
+#error "This file was generated using the moc from 6.10.0. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -99,6 +99,7 @@ template <> constexpr inline auto UIMediumManagerWidget::qt_create_metaobjectdat
         "sigCreateMedium",
         "",
         "sigCopyMedium",
+        "QUuid",
         "uMediumId",
         "sigMediumDetailsVisibilityChanged",
         "fVisible",
@@ -133,6 +134,7 @@ template <> constexpr inline auto UIMediumManagerWidget::qt_create_metaobjectdat
         "sltHandleCurrentTabChanged",
         "sltHandleCurrentItemChanged",
         "sltHandleContextMenuRequest",
+        "QPoint",
         "position",
         "sltPerformTablesAdjustment",
         "sltHandlePerformSearch",
@@ -145,90 +147,90 @@ template <> constexpr inline auto UIMediumManagerWidget::qt_create_metaobjectdat
         QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigCopyMedium'
         QtMocHelpers::SignalData<void(const QUuid &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QUuid, 4 },
+            { 0x80000000 | 4, 5 },
         }}),
         // Signal 'sigMediumDetailsVisibilityChanged'
-        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 6 },
+        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 7 },
         }}),
         // Signal 'sigAcceptAllowed'
-        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 8 },
+        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 9 },
         }}),
         // Signal 'sigRejectAllowed'
-        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 8 },
+        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 9 },
         }}),
         // Slot 'sltResetMediumDetailsChanges'
-        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
-        // Slot 'sltApplyMediumDetailsChanges'
         QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
+        // Slot 'sltApplyMediumDetailsChanges'
+        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'sltHandleMediumCreated'
-        QtMocHelpers::SlotData<void(const QUuid &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QUuid, 13 },
+        QtMocHelpers::SlotData<void(const QUuid &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 4, 14 },
         }}),
         // Slot 'sltHandleMediumDeleted'
-        QtMocHelpers::SlotData<void(const QUuid &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QUuid, 13 },
+        QtMocHelpers::SlotData<void(const QUuid &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 4, 14 },
         }}),
         // Slot 'sltHandleMediumEnumerationStart'
-        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltHandleMediumEnumerated'
-        QtMocHelpers::SlotData<void(const QUuid &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QUuid, 13 },
+        QtMocHelpers::SlotData<void(const QUuid &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 4, 14 },
         }}),
         // Slot 'sltHandleMediumEnumerationFinish'
-        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltHandleMachineStateChange'
-        QtMocHelpers::SlotData<void(const QUuid &, const KMachineState)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QUuid, 19 }, { 0x80000000 | 20, 21 },
+        QtMocHelpers::SlotData<void(const QUuid &, const KMachineState)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 4, 20 }, { 0x80000000 | 21, 22 },
         }}),
         // Slot 'sltAddMedium'
-        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltCreateMedium'
         QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltCopyMedium'
+        // Slot 'sltCreateMedium'
         QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltMoveMedium'
+        // Slot 'sltCopyMedium'
         QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltRemoveMedium'
+        // Slot 'sltMoveMedium'
         QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltReleaseMedium'
+        // Slot 'sltRemoveMedium'
         QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltClear'
+        // Slot 'sltReleaseMedium'
         QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltClear'
+        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltToggleMediumDetailsVisibility'
-        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 6 },
+        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 7 },
         }}),
         // Slot 'sltToggleMediumSearchVisibility'
-        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 6 },
+        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 7 },
         }}),
         // Slot 'sltRefreshAll'
-        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltEditVISO'
         QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltHandleMoveProgressFinished'
+        // Slot 'sltEditVISO'
         QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltHandleResizeProgressFinished'
+        // Slot 'sltHandleMoveProgressFinished'
         QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltHandleCurrentTabChanged'
+        // Slot 'sltHandleResizeProgressFinished'
         QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltHandleCurrentItemChanged'
+        // Slot 'sltHandleCurrentTabChanged'
         QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltHandleCurrentItemChanged'
+        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltHandleContextMenuRequest'
-        QtMocHelpers::SlotData<void(const QPoint &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QPoint, 38 },
+        QtMocHelpers::SlotData<void(const QPoint &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 39, 40 },
         }}),
         // Slot 'sltPerformTablesAdjustment'
-        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltHandlePerformSearch'
-        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltDetachCOM'
         QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltRetranslateUI'
+        // Slot 'sltHandlePerformSearch'
         QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltDetachCOM'
+        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltRetranslateUI'
+        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
     };
     QtMocHelpers::UintData qt_properties {
     };
@@ -253,18 +255,18 @@ void UIMediumManagerWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
         case 0: _t->sigCreateMedium(); break;
-        case 1: _t->sigCopyMedium((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 2: _t->sigMediumDetailsVisibilityChanged((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 3: _t->sigAcceptAllowed((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 4: _t->sigRejectAllowed((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 1: _t->sigCopyMedium((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 2: _t->sigMediumDetailsVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 3: _t->sigAcceptAllowed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 4: _t->sigRejectAllowed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 5: _t->sltResetMediumDetailsChanges(); break;
         case 6: _t->sltApplyMediumDetailsChanges(); break;
-        case 7: _t->sltHandleMediumCreated((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 8: _t->sltHandleMediumDeleted((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 7: _t->sltHandleMediumCreated((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 8: _t->sltHandleMediumDeleted((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
         case 9: _t->sltHandleMediumEnumerationStart(); break;
-        case 10: _t->sltHandleMediumEnumerated((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 10: _t->sltHandleMediumEnumerated((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
         case 11: _t->sltHandleMediumEnumerationFinish(); break;
-        case 12: _t->sltHandleMachineStateChange((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<KMachineState>>(_a[2]))); break;
+        case 12: _t->sltHandleMachineStateChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMachineState>>(_a[2]))); break;
         case 13: _t->sltAddMedium(); break;
         case 14: _t->sltCreateMedium(); break;
         case 15: _t->sltCopyMedium(); break;
@@ -272,15 +274,15 @@ void UIMediumManagerWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c
         case 17: _t->sltRemoveMedium(); break;
         case 18: _t->sltReleaseMedium(); break;
         case 19: _t->sltClear(); break;
-        case 20: _t->sltToggleMediumDetailsVisibility((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 21: _t->sltToggleMediumSearchVisibility((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 20: _t->sltToggleMediumDetailsVisibility((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 21: _t->sltToggleMediumSearchVisibility((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 22: _t->sltRefreshAll(); break;
         case 23: _t->sltEditVISO(); break;
         case 24: _t->sltHandleMoveProgressFinished(); break;
         case 25: _t->sltHandleResizeProgressFinished(); break;
         case 26: _t->sltHandleCurrentTabChanged(); break;
         case 27: _t->sltHandleCurrentItemChanged(); break;
-        case 28: _t->sltHandleContextMenuRequest((*reinterpret_cast< std::add_pointer_t<QPoint>>(_a[1]))); break;
+        case 28: _t->sltHandleContextMenuRequest((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
         case 29: _t->sltPerformTablesAdjustment(); break;
         case 30: _t->sltHandlePerformSearch(); break;
         case 31: _t->sltDetachCOM(); break;
@@ -428,7 +430,7 @@ void UIMediumManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int
         switch (_id) {
         case 0: _t->sigDataChangeRejected(); break;
         case 1: _t->sigDataChangeAccepted(); break;
-        case 2: _t->sltHandleButtonBoxClick((*reinterpret_cast< std::add_pointer_t<QAbstractButton*>>(_a[1]))); break;
+        case 2: _t->sltHandleButtonBoxClick((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1]))); break;
         case 3: _t->sltRetranslateUI(); break;
         default: ;
         }
