@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'UIVirtualBoxManager.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.2)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -19,7 +19,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'UIVirtualBoxManager.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.9.2. It"
+#error "This file was generated using the moc from 6.10.0. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -58,6 +58,7 @@ template <> constexpr inline auto UIVirtualBoxManager::qt_create_metaobjectdata<
         "enmTask",
         "sltCreateMedium",
         "sltCopyMedium",
+        "QUuid",
         "uMediumId",
         "sltDetachToolPane",
         "UIToolType",
@@ -175,178 +176,178 @@ template <> constexpr inline auto UIVirtualBoxManager::qt_create_metaobjectdata<
         QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltCopyMedium'
         QtMocHelpers::SlotData<void(const QUuid &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QUuid, 19 },
+            { 0x80000000 | 19, 20 },
         }}),
         // Slot 'sltDetachToolPane'
-        QtMocHelpers::SlotData<void(UIToolType)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 21, 22 },
+        QtMocHelpers::SlotData<void(UIToolType)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 22, 23 },
         }}),
         // Slot 'sltRetranslateUI'
-        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltHandleMenuPrepare'
-        QtMocHelpers::SlotData<void(int, QMenu *)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Int, 25 }, { 0x80000000 | 26, 27 },
+        QtMocHelpers::SlotData<void(int, QMenu *)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Int, 26 }, { 0x80000000 | 27, 28 },
         }}),
         // Slot 'sltOpenManagerWindow'
-        QtMocHelpers::SlotData<void(UIToolType)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 21, 29 },
+        QtMocHelpers::SlotData<void(UIToolType)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 22, 30 },
         }}),
         // Slot 'sltOpenManagerWindow'
-        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
         // Slot 'sltOpenManagerWindowDefault'
-        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltEmbedManagerWindow'
-        QtMocHelpers::SlotData<void(UIToolType)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 21, 29 },
-        }}),
-        // Slot 'sltEmbedManagerWindow'
-        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
-        // Slot 'sltCloseManagerWindow'
         QtMocHelpers::SlotData<void(UIToolType)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 21, 29 },
+            { 0x80000000 | 22, 30 },
+        }}),
+        // Slot 'sltEmbedManagerWindow'
+        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
+        // Slot 'sltCloseManagerWindow'
+        QtMocHelpers::SlotData<void(UIToolType)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 22, 30 },
         }}),
         // Slot 'sltCloseManagerWindow'
-        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
         // Slot 'sltEmbedManagerWindowDefault'
-        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltCloseManagerWindowDefault'
         QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltOpenImportApplianceWizard'
+        // Slot 'sltCloseManagerWindowDefault'
         QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltOpenExportApplianceWizard'
+        // Slot 'sltOpenImportApplianceWizard'
         QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltOpenPreferencesDialog'
+        // Slot 'sltOpenExportApplianceWizard'
         QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltClosePreferencesDialog'
+        // Slot 'sltOpenPreferencesDialog'
         QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltClosePreferencesDialog'
+        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltPerformSwitchToTool'
-        QtMocHelpers::SlotData<void(QAction *)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 40, 41 },
+        QtMocHelpers::SlotData<void(QAction *)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 41, 42 },
         }}),
         // Slot 'sltPerformExit'
-        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltOpenWizard'
-        QtMocHelpers::SlotData<void(WizardType)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 44, 29 },
+        QtMocHelpers::SlotData<void(WizardType)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 45, 30 },
         }}),
         // Slot 'sltCloseWizard'
-        QtMocHelpers::SlotData<void(WizardType)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 44, 29 },
+        QtMocHelpers::SlotData<void(WizardType)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 45, 30 },
         }}),
         // Slot 'sltOpenNewMachineWizard'
-        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltOpenAddMachineDialog'
         QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltOpenGroupNameEditor'
+        // Slot 'sltOpenAddMachineDialog'
         QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltDisbandGroup'
+        // Slot 'sltOpenGroupNameEditor'
         QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltDisbandGroup'
+        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltOpenSettingsDialog'
-        QtMocHelpers::SlotData<void(QString, QString, const QUuid &)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QString, 51 }, { QMetaType::QString, 52 }, { QMetaType::QUuid, 53 },
+        QtMocHelpers::SlotData<void(QString, QString, const QUuid &)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::QString, 52 }, { QMetaType::QString, 53 }, { 0x80000000 | 19, 54 },
         }}),
         // Slot 'sltOpenSettingsDialog'
-        QtMocHelpers::SlotData<void(QString, QString)>(50, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
-            { QMetaType::QString, 51 }, { QMetaType::QString, 52 },
+        QtMocHelpers::SlotData<void(QString, QString)>(51, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
+            { QMetaType::QString, 52 }, { QMetaType::QString, 53 },
         }}),
         // Slot 'sltOpenSettingsDialog'
-        QtMocHelpers::SlotData<void(QString)>(50, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
-            { QMetaType::QString, 51 },
+        QtMocHelpers::SlotData<void(QString)>(51, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
+            { QMetaType::QString, 52 },
         }}),
         // Slot 'sltOpenSettingsDialog'
-        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
         // Slot 'sltOpenSettingsDialogDefault'
-        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltCloseSettingsDialog'
         QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltOpenCloneMachineWizard'
+        // Slot 'sltCloseSettingsDialog'
         QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformMachineMove'
+        // Slot 'sltOpenCloneMachineWizard'
         QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformMachineRemove'
+        // Slot 'sltPerformMachineMove'
         QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformMachineMoveToNewGroup'
+        // Slot 'sltPerformMachineRemove'
         QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformMachineMoveToSpecificGroup'
+        // Slot 'sltPerformMachineMoveToNewGroup'
         QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformStartOrShowMachine'
+        // Slot 'sltPerformMachineMoveToSpecificGroup'
         QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformStartMachine'
+        // Slot 'sltPerformStartOrShowMachine'
         QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformStartMachineNormal'
+        // Slot 'sltPerformStartMachine'
         QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformStartMachineHeadless'
+        // Slot 'sltPerformStartMachineNormal'
         QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformStartMachineDetachable'
+        // Slot 'sltPerformStartMachineHeadless'
         QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformShowMachine'
+        // Slot 'sltPerformStartMachineDetachable'
         QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCreateConsoleConnectionForGroup'
+        // Slot 'sltPerformShowMachine'
         QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCreateConsoleConnectionForMachine'
+        // Slot 'sltPerformCreateConsoleConnectionForGroup'
         QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformDeleteConsoleConnectionForGroup'
+        // Slot 'sltPerformCreateConsoleConnectionForMachine'
         QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformDeleteConsoleConnectionForMachine'
+        // Slot 'sltPerformDeleteConsoleConnectionForGroup'
         QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltCopyConsoleConnectionFingerprint'
+        // Slot 'sltPerformDeleteConsoleConnectionForMachine'
         QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCopyCommandSerialUnix'
+        // Slot 'sltCopyConsoleConnectionFingerprint'
         QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCopyCommandSerialWindows'
+        // Slot 'sltPerformCopyCommandSerialUnix'
         QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCopyCommandVNCUnix'
+        // Slot 'sltPerformCopyCommandSerialWindows'
         QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCopyCommandVNCWindows'
+        // Slot 'sltPerformCopyCommandVNCUnix'
         QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformShowLog'
+        // Slot 'sltPerformCopyCommandVNCWindows'
         QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltPerformShowLog'
+        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltHandleConsoleLogRead'
-        QtMocHelpers::SlotData<void(const QString &, const QString &)>(77, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QString, 78 }, { QMetaType::QString, 79 },
+        QtMocHelpers::SlotData<void(const QString &, const QString &)>(78, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::QString, 79 }, { QMetaType::QString, 80 },
         }}),
         // Slot 'sltExecuteExternalApplication'
-        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformDiscardMachineState'
         QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltPerformDiscardMachineState'
+        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltPerformPauseOrResumeMachine'
-        QtMocHelpers::SlotData<void(bool)>(82, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 83 },
+        QtMocHelpers::SlotData<void(bool)>(83, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 84 },
         }}),
         // Slot 'sltPerformResetMachine'
-        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformDetachMachineUI'
         QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformSaveMachineState'
+        // Slot 'sltPerformDetachMachineUI'
         QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformTerminateMachine'
+        // Slot 'sltPerformSaveMachineState'
         QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformShutdownMachine'
+        // Slot 'sltPerformTerminateMachine'
         QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformPowerOffMachine'
+        // Slot 'sltPerformShutdownMachine'
         QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltPerformPowerOffMachine'
+        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltHandlePoweredOffMachine'
-        QtMocHelpers::SlotData<void(bool, bool)>(90, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 91 }, { QMetaType::Bool, 92 },
+        QtMocHelpers::SlotData<void(bool, bool)>(91, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 92 }, { QMetaType::Bool, 93 },
         }}),
         // Slot 'sltPerformSwitchToMachineTool'
-        QtMocHelpers::SlotData<void(QAction *)>(93, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 40, 41 },
+        QtMocHelpers::SlotData<void(QAction *)>(94, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 41, 42 },
         }}),
         // Slot 'sltPerformRefreshMachine'
-        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltShowMachineInFileManager'
         QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCreateMachineShortcut'
+        // Slot 'sltShowMachineInFileManager'
         QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformGroupSorting'
+        // Slot 'sltPerformCreateMachineShortcut'
         QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltPerformGroupSorting'
+        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltPerformMachineSearchWidgetVisibilityToggling'
-        QtMocHelpers::SlotData<void(bool)>(98, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 99 },
+        QtMocHelpers::SlotData<void(bool)>(99, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 100 },
         }}),
         // Slot 'sltPerformShowHelpBrowser'
-        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPrivate, QMetaType::Void),
     };
     QtMocHelpers::UintData qt_properties {
     };
@@ -375,24 +376,24 @@ void UIVirtualBoxManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c,
         case 2: _t->sltHandleUpdateActionAppearanceRequest(); break;
         case 3: _t->sltHandleCommitData(); break;
         case 4: _t->sltHandleMediumEnumerationFinish(); break;
-        case 5: _t->sltHandleOpenUrlCall((*reinterpret_cast< std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
+        case 5: _t->sltHandleOpenUrlCall((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
         case 6: _t->sltHandleOpenUrlCall(); break;
         case 7: _t->sltCheckUSBAccesibility(); break;
         case 8: _t->sltHandleChooserPaneSelectionChange(); break;
         case 9: _t->sltHandleGlobalToolTypeChange(); break;
         case 10: _t->sltHandleMachineToolTypeChange(); break;
-        case 11: _t->sltExecuteHomeTask((*reinterpret_cast< std::add_pointer_t<HomeTask>>(_a[1]))); break;
+        case 11: _t->sltExecuteHomeTask((*reinterpret_cast<std::add_pointer_t<HomeTask>>(_a[1]))); break;
         case 12: _t->sltCreateMedium(); break;
-        case 13: _t->sltCopyMedium((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1]))); break;
-        case 14: _t->sltDetachToolPane((*reinterpret_cast< std::add_pointer_t<UIToolType>>(_a[1]))); break;
+        case 13: _t->sltCopyMedium((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
+        case 14: _t->sltDetachToolPane((*reinterpret_cast<std::add_pointer_t<UIToolType>>(_a[1]))); break;
         case 15: _t->sltRetranslateUI(); break;
-        case 16: _t->sltHandleMenuPrepare((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QMenu*>>(_a[2]))); break;
-        case 17: _t->sltOpenManagerWindow((*reinterpret_cast< std::add_pointer_t<UIToolType>>(_a[1]))); break;
+        case 16: _t->sltHandleMenuPrepare((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2]))); break;
+        case 17: _t->sltOpenManagerWindow((*reinterpret_cast<std::add_pointer_t<UIToolType>>(_a[1]))); break;
         case 18: _t->sltOpenManagerWindow(); break;
         case 19: _t->sltOpenManagerWindowDefault(); break;
-        case 20: _t->sltEmbedManagerWindow((*reinterpret_cast< std::add_pointer_t<UIToolType>>(_a[1]))); break;
+        case 20: _t->sltEmbedManagerWindow((*reinterpret_cast<std::add_pointer_t<UIToolType>>(_a[1]))); break;
         case 21: _t->sltEmbedManagerWindow(); break;
-        case 22: _t->sltCloseManagerWindow((*reinterpret_cast< std::add_pointer_t<UIToolType>>(_a[1]))); break;
+        case 22: _t->sltCloseManagerWindow((*reinterpret_cast<std::add_pointer_t<UIToolType>>(_a[1]))); break;
         case 23: _t->sltCloseManagerWindow(); break;
         case 24: _t->sltEmbedManagerWindowDefault(); break;
         case 25: _t->sltCloseManagerWindowDefault(); break;
@@ -400,17 +401,17 @@ void UIVirtualBoxManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c,
         case 27: _t->sltOpenExportApplianceWizard(); break;
         case 28: _t->sltOpenPreferencesDialog(); break;
         case 29: _t->sltClosePreferencesDialog(); break;
-        case 30: _t->sltPerformSwitchToTool((*reinterpret_cast< std::add_pointer_t<QAction*>>(_a[1]))); break;
+        case 30: _t->sltPerformSwitchToTool((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
         case 31: _t->sltPerformExit(); break;
-        case 32: _t->sltOpenWizard((*reinterpret_cast< std::add_pointer_t<WizardType>>(_a[1]))); break;
-        case 33: _t->sltCloseWizard((*reinterpret_cast< std::add_pointer_t<WizardType>>(_a[1]))); break;
+        case 32: _t->sltOpenWizard((*reinterpret_cast<std::add_pointer_t<WizardType>>(_a[1]))); break;
+        case 33: _t->sltCloseWizard((*reinterpret_cast<std::add_pointer_t<WizardType>>(_a[1]))); break;
         case 34: _t->sltOpenNewMachineWizard(); break;
         case 35: _t->sltOpenAddMachineDialog(); break;
         case 36: _t->sltOpenGroupNameEditor(); break;
         case 37: _t->sltDisbandGroup(); break;
-        case 38: _t->sltOpenSettingsDialog((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[3]))); break;
-        case 39: _t->sltOpenSettingsDialog((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2]))); break;
-        case 40: _t->sltOpenSettingsDialog((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
+        case 38: _t->sltOpenSettingsDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[3]))); break;
+        case 39: _t->sltOpenSettingsDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
+        case 40: _t->sltOpenSettingsDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
         case 41: _t->sltOpenSettingsDialog(); break;
         case 42: _t->sltOpenSettingsDialogDefault(); break;
         case 43: _t->sltCloseSettingsDialog(); break;
@@ -435,23 +436,23 @@ void UIVirtualBoxManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c,
         case 62: _t->sltPerformCopyCommandVNCUnix(); break;
         case 63: _t->sltPerformCopyCommandVNCWindows(); break;
         case 64: _t->sltPerformShowLog(); break;
-        case 65: _t->sltHandleConsoleLogRead((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2]))); break;
+        case 65: _t->sltHandleConsoleLogRead((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
         case 66: _t->sltExecuteExternalApplication(); break;
         case 67: _t->sltPerformDiscardMachineState(); break;
-        case 68: _t->sltPerformPauseOrResumeMachine((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 68: _t->sltPerformPauseOrResumeMachine((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 69: _t->sltPerformResetMachine(); break;
         case 70: _t->sltPerformDetachMachineUI(); break;
         case 71: _t->sltPerformSaveMachineState(); break;
         case 72: _t->sltPerformTerminateMachine(); break;
         case 73: _t->sltPerformShutdownMachine(); break;
         case 74: _t->sltPerformPowerOffMachine(); break;
-        case 75: _t->sltHandlePoweredOffMachine((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2]))); break;
-        case 76: _t->sltPerformSwitchToMachineTool((*reinterpret_cast< std::add_pointer_t<QAction*>>(_a[1]))); break;
+        case 75: _t->sltHandlePoweredOffMachine((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
+        case 76: _t->sltPerformSwitchToMachineTool((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
         case 77: _t->sltPerformRefreshMachine(); break;
         case 78: _t->sltShowMachineInFileManager(); break;
         case 79: _t->sltPerformCreateMachineShortcut(); break;
         case 80: _t->sltPerformGroupSorting(); break;
-        case 81: _t->sltPerformMachineSearchWidgetVisibilityToggling((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 81: _t->sltPerformMachineSearchWidgetVisibilityToggling((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 82: _t->sltPerformShowHelpBrowser(); break;
         default: ;
         }
@@ -459,13 +460,6 @@ void UIVirtualBoxManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c,
     if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
         switch (_id) {
         default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
-        case 5:
-            switch (*reinterpret_cast<int*>(_a[1])) {
-            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
-            case 0:
-                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QUrl> >(); break;
-            }
-            break;
         case 14:
             switch (*reinterpret_cast<int*>(_a[1])) {
             default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
