@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'UIConsoleEventHandler.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.2)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -18,7 +18,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'UIConsoleEventHandler.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.9.2. It"
+#error "This file was generated using the moc from 6.10.0. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -85,6 +85,7 @@ template <> constexpr inline auto UIConsoleEventHandler::qt_create_metaobjectdat
         "KGuestMonitorChangedEventType",
         "type",
         "uScreenId",
+        "QRect",
         "screenGeo",
         "sigRuntimeError",
         "fFatal",
@@ -152,25 +153,25 @@ template <> constexpr inline auto UIConsoleEventHandler::qt_create_metaobjectdat
         QtMocHelpers::SignalData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigGuestMonitorChange'
         QtMocHelpers::SignalData<void(KGuestMonitorChangedEventType, ulong, QRect)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 44, 45 }, { QMetaType::ULong, 46 }, { QMetaType::QRect, 47 },
+            { 0x80000000 | 44, 45 }, { QMetaType::ULong, 46 }, { 0x80000000 | 47, 48 },
         }}),
         // Signal 'sigRuntimeError'
-        QtMocHelpers::SignalData<void(bool, QString, QString)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 49 }, { QMetaType::QString, 50 }, { QMetaType::QString, 51 },
+        QtMocHelpers::SignalData<void(bool, QString, QString)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 50 }, { QMetaType::QString, 51 }, { QMetaType::QString, 52 },
         }}),
         // Signal 'sigAudioAdapterChange'
-        QtMocHelpers::SignalData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SignalData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigClipboardModeChange'
-        QtMocHelpers::SignalData<void(KClipboardMode)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 54, 55 },
+        QtMocHelpers::SignalData<void(KClipboardMode)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 55, 56 },
         }}),
         // Signal 'sigClipboardError'
-        QtMocHelpers::SignalData<void(const QString &)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 57 },
+        QtMocHelpers::SignalData<void(const QString &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 58 },
         }}),
         // Signal 'sigDnDModeChange'
-        QtMocHelpers::SignalData<void(KDnDMode)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 59, 55 },
+        QtMocHelpers::SignalData<void(KDnDMode)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 60, 56 },
         }}),
     };
     QtMocHelpers::UintData qt_properties {
@@ -195,27 +196,27 @@ void UIConsoleEventHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c
     auto *_t = static_cast<UIConsoleEventHandler *>(_o);
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
-        case 0: _t->sigMousePointerShapeChange((*reinterpret_cast< std::add_pointer_t<UIMousePointerShapeData>>(_a[1]))); break;
-        case 1: _t->sigMouseCapabilityChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[5]))); break;
-        case 2: _t->sigCursorPositionChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[3]))); break;
-        case 3: _t->sigKeyboardLedsChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
-        case 4: _t->sigStateChange((*reinterpret_cast< std::add_pointer_t<KMachineState>>(_a[1]))); break;
+        case 0: _t->sigMousePointerShapeChange((*reinterpret_cast<std::add_pointer_t<UIMousePointerShapeData>>(_a[1]))); break;
+        case 1: _t->sigMouseCapabilityChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
+        case 2: _t->sigCursorPositionChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[3]))); break;
+        case 3: _t->sigKeyboardLedsChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 4: _t->sigStateChange((*reinterpret_cast<std::add_pointer_t<KMachineState>>(_a[1]))); break;
         case 5: _t->sigAdditionsChange(); break;
-        case 6: _t->sigNetworkAdapterChange((*reinterpret_cast< std::add_pointer_t<CNetworkAdapter>>(_a[1]))); break;
-        case 7: _t->sigStorageDeviceChange((*reinterpret_cast< std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
-        case 8: _t->sigMediumChange((*reinterpret_cast< std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
+        case 6: _t->sigNetworkAdapterChange((*reinterpret_cast<std::add_pointer_t<CNetworkAdapter>>(_a[1]))); break;
+        case 7: _t->sigStorageDeviceChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 8: _t->sigMediumChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
         case 9: _t->sigVRDEChange(); break;
         case 10: _t->sigRecordingChange(); break;
         case 11: _t->sigUSBControllerChange(); break;
-        case 12: _t->sigUSBDeviceStateChange((*reinterpret_cast< std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
+        case 12: _t->sigUSBDeviceStateChange((*reinterpret_cast<std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
         case 13: _t->sigSharedFolderChange(); break;
         case 14: _t->sigCPUExecutionCapChange(); break;
-        case 15: _t->sigGuestMonitorChange((*reinterpret_cast< std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QRect>>(_a[3]))); break;
-        case 16: _t->sigRuntimeError((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[3]))); break;
+        case 15: _t->sigGuestMonitorChange((*reinterpret_cast<std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3]))); break;
+        case 16: _t->sigRuntimeError((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
         case 17: _t->sigAudioAdapterChange(); break;
-        case 18: _t->sigClipboardModeChange((*reinterpret_cast< std::add_pointer_t<KClipboardMode>>(_a[1]))); break;
-        case 19: _t->sigClipboardError((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 20: _t->sigDnDModeChange((*reinterpret_cast< std::add_pointer_t<KDnDMode>>(_a[1]))); break;
+        case 18: _t->sigClipboardModeChange((*reinterpret_cast<std::add_pointer_t<KClipboardMode>>(_a[1]))); break;
+        case 19: _t->sigClipboardError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 20: _t->sigDnDModeChange((*reinterpret_cast<std::add_pointer_t<KDnDMode>>(_a[1]))); break;
         default: ;
         }
     }
