@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'UIMachine.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.2)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -18,7 +18,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'UIMachine.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.9.2. It"
+#error "This file was generated using the moc from 6.10.0. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -57,6 +57,7 @@ template <> constexpr inline auto UIMachine::qt_create_metaobjectdata<qt_meta_ta
         "KGuestMonitorChangedEventType",
         "emnChangeType",
         "uScreenId",
+        "QRect",
         "screenGeo",
         "sigMachineStateChange",
         "sigMediumChange",
@@ -158,124 +159,124 @@ template <> constexpr inline auto UIMachine::qt_create_metaobjectdata<qt_meta_ta
         }}),
         // Signal 'sigGuestMonitorChange'
         QtMocHelpers::SignalData<void(KGuestMonitorChangedEventType, ulong, QRect)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 16, 17 }, { QMetaType::ULong, 18 }, { QMetaType::QRect, 19 },
+            { 0x80000000 | 16, 17 }, { QMetaType::ULong, 18 }, { 0x80000000 | 19, 20 },
         }}),
         // Signal 'sigMachineStateChange'
-        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigMediumChange'
-        QtMocHelpers::SignalData<void(const CMediumAttachment &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 22, 23 },
+        QtMocHelpers::SignalData<void(const CMediumAttachment &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 23, 24 },
         }}),
         // Signal 'sigNetworkAdapterChange'
-        QtMocHelpers::SignalData<void(const CNetworkAdapter &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 25, 26 },
+        QtMocHelpers::SignalData<void(const CNetworkAdapter &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 26, 27 },
         }}),
         // Signal 'sigRecordingChange'
-        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigSharedFolderChange'
         QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
+        // Signal 'sigSharedFolderChange'
+        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigStorageDeviceChange'
-        QtMocHelpers::SignalData<void(const CMediumAttachment &, bool, bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 22, 30 }, { QMetaType::Bool, 31 }, { QMetaType::Bool, 32 },
+        QtMocHelpers::SignalData<void(const CMediumAttachment &, bool, bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 23, 31 }, { QMetaType::Bool, 32 }, { QMetaType::Bool, 33 },
         }}),
         // Signal 'sigUSBControllerChange'
-        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigUSBDeviceStateChange'
-        QtMocHelpers::SignalData<void(const CUSBDevice &, bool, const CVirtualBoxErrorInfo &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 35, 36 }, { QMetaType::Bool, 37 }, { 0x80000000 | 38, 39 },
+        QtMocHelpers::SignalData<void(const CUSBDevice &, bool, const CVirtualBoxErrorInfo &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 36, 37 }, { QMetaType::Bool, 38 }, { 0x80000000 | 39, 40 },
         }}),
         // Signal 'sigVRDEChange'
-        QtMocHelpers::SignalData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SignalData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigRuntimeError'
-        QtMocHelpers::SignalData<void(bool, const QString &, const QString &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 42 }, { QMetaType::QString, 43 }, { QMetaType::QString, 44 },
+        QtMocHelpers::SignalData<void(bool, const QString &, const QString &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 43 }, { QMetaType::QString, 44 }, { QMetaType::QString, 45 },
         }}),
         // Signal 'sigKeyboardLedsChange'
-        QtMocHelpers::SignalData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SignalData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigKeyboardStateChange'
-        QtMocHelpers::SignalData<void(int)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Int, 47 },
+        QtMocHelpers::SignalData<void(int)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Int, 48 },
         }}),
         // Signal 'sigMousePointerShapeChange'
-        QtMocHelpers::SignalData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigMouseCapabilityChange'
         QtMocHelpers::SignalData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigCursorPositionChange'
+        // Signal 'sigMouseCapabilityChange'
         QtMocHelpers::SignalData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
+        // Signal 'sigCursorPositionChange'
+        QtMocHelpers::SignalData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigMouseStateChange'
-        QtMocHelpers::SignalData<void(int)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Int, 47 },
+        QtMocHelpers::SignalData<void(int)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Int, 48 },
         }}),
         // Signal 'sigHostScreenCountChange'
-        QtMocHelpers::SignalData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigHostScreenGeometryChange'
         QtMocHelpers::SignalData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigHostScreenAvailableAreaChange'
+        // Signal 'sigHostScreenGeometryChange'
         QtMocHelpers::SignalData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
+        // Signal 'sigHostScreenAvailableAreaChange'
+        QtMocHelpers::SignalData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'sltInstallGuestAdditionsFrom'
-        QtMocHelpers::SlotData<void(const QString &)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 56 },
+        QtMocHelpers::SlotData<void(const QString &)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 57 },
         }}),
         // Slot 'sltMountDVDAdHoc'
-        QtMocHelpers::SlotData<void(const QString &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 56 },
+        QtMocHelpers::SlotData<void(const QString &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 57 },
         }}),
         // Slot 'setKeyboardState'
-        QtMocHelpers::SlotData<void(int)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Int, 59 },
+        QtMocHelpers::SlotData<void(int)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Int, 60 },
         }}),
         // Slot 'setMouseState'
-        QtMocHelpers::SlotData<void(int)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Int, 61 },
+        QtMocHelpers::SlotData<void(int)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Int, 62 },
         }}),
         // Slot 'closeRuntimeUI'
-        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'sltChangeVisualState'
-        QtMocHelpers::SlotData<void(UIVisualStateType)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(UIVisualStateType)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { 0x80000000 | 4, 5 },
         }}),
         // Slot 'sltHandleAdditionsActualChange'
-        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltHandleAudioAdapterChange'
         QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltHandleRecordingChange'
+        // Slot 'sltHandleAudioAdapterChange'
         QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltHandleRecordingChange'
+        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltHandleStorageDeviceChange'
-        QtMocHelpers::SlotData<void(const CMediumAttachment &, bool, bool)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 22, 30 }, { QMetaType::Bool, 31 }, { QMetaType::Bool, 32 },
+        QtMocHelpers::SlotData<void(const CMediumAttachment &, bool, bool)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 23, 31 }, { QMetaType::Bool, 32 }, { QMetaType::Bool, 33 },
         }}),
         // Slot 'sltHandleVRDEChange'
-        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltHandleHostScreenCountChange'
         QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltHandleHostScreenGeometryChange'
+        // Slot 'sltHandleHostScreenCountChange'
         QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltHandleHostScreenAvailableAreaChange'
+        // Slot 'sltHandleHostScreenGeometryChange'
         QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltHandleHostScreenAvailableAreaChange'
+        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltHandleGuestMonitorChange'
-        QtMocHelpers::SlotData<void(KGuestMonitorChangedEventType, ulong, QRect)>(72, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 16, 73 }, { QMetaType::ULong, 18 }, { QMetaType::QRect, 19 },
+        QtMocHelpers::SlotData<void(KGuestMonitorChangedEventType, ulong, QRect)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 16, 74 }, { QMetaType::ULong, 18 }, { 0x80000000 | 19, 20 },
         }}),
         // Slot 'sltHandleKeyboardLedsChange'
-        QtMocHelpers::SlotData<void(bool, bool, bool)>(74, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 75 }, { QMetaType::Bool, 76 }, { QMetaType::Bool, 77 },
+        QtMocHelpers::SlotData<void(bool, bool, bool)>(75, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 76 }, { QMetaType::Bool, 77 }, { QMetaType::Bool, 78 },
         }}),
         // Slot 'sltHidLedsSyncStateChanged'
-        QtMocHelpers::SlotData<void(bool)>(78, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 79 },
+        QtMocHelpers::SlotData<void(bool)>(79, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 80 },
         }}),
         // Slot 'sltMousePointerShapeChange'
-        QtMocHelpers::SlotData<void(const UIMousePointerShapeData &)>(80, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 81, 82 },
+        QtMocHelpers::SlotData<void(const UIMousePointerShapeData &)>(81, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 82, 83 },
         }}),
         // Slot 'sltMouseCapabilityChange'
-        QtMocHelpers::SlotData<void(bool, bool, bool, bool, bool)>(83, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 84 }, { QMetaType::Bool, 85 }, { QMetaType::Bool, 86 }, { QMetaType::Bool, 87 },
-            { QMetaType::Bool, 88 },
+        QtMocHelpers::SlotData<void(bool, bool, bool, bool, bool)>(84, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 85 }, { QMetaType::Bool, 86 }, { QMetaType::Bool, 87 }, { QMetaType::Bool, 88 },
+            { QMetaType::Bool, 89 },
         }}),
         // Slot 'sltCursorPositionChange'
-        QtMocHelpers::SlotData<void(bool, unsigned long, unsigned long)>(89, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 90 }, { QMetaType::ULong, 91 }, { QMetaType::ULong, 92 },
+        QtMocHelpers::SlotData<void(bool, unsigned long, unsigned long)>(90, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 91 }, { QMetaType::ULong, 92 }, { QMetaType::ULong, 93 },
         }}),
     };
     QtMocHelpers::UintData qt_properties {
@@ -301,53 +302,53 @@ void UIMachine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, v
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
         case 0: _t->sigInitialized(); break;
-        case 1: _t->sigRequestAsyncVisualStateChange((*reinterpret_cast< std::add_pointer_t<UIVisualStateType>>(_a[1]))); break;
+        case 1: _t->sigRequestAsyncVisualStateChange((*reinterpret_cast<std::add_pointer_t<UIVisualStateType>>(_a[1]))); break;
         case 2: _t->sigAdditionsStateChange(); break;
         case 3: _t->sigAdditionsStateActualChange(); break;
         case 4: _t->sigAudioAdapterChange(); break;
-        case 5: _t->sigClipboardModeChange((*reinterpret_cast< std::add_pointer_t<KClipboardMode>>(_a[1]))); break;
+        case 5: _t->sigClipboardModeChange((*reinterpret_cast<std::add_pointer_t<KClipboardMode>>(_a[1]))); break;
         case 6: _t->sigCPUExecutionCapChange(); break;
-        case 7: _t->sigDnDModeChange((*reinterpret_cast< std::add_pointer_t<KDnDMode>>(_a[1]))); break;
-        case 8: _t->sigGuestMonitorChange((*reinterpret_cast< std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QRect>>(_a[3]))); break;
+        case 7: _t->sigDnDModeChange((*reinterpret_cast<std::add_pointer_t<KDnDMode>>(_a[1]))); break;
+        case 8: _t->sigGuestMonitorChange((*reinterpret_cast<std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3]))); break;
         case 9: _t->sigMachineStateChange(); break;
-        case 10: _t->sigMediumChange((*reinterpret_cast< std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
-        case 11: _t->sigNetworkAdapterChange((*reinterpret_cast< std::add_pointer_t<CNetworkAdapter>>(_a[1]))); break;
+        case 10: _t->sigMediumChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
+        case 11: _t->sigNetworkAdapterChange((*reinterpret_cast<std::add_pointer_t<CNetworkAdapter>>(_a[1]))); break;
         case 12: _t->sigRecordingChange(); break;
         case 13: _t->sigSharedFolderChange(); break;
-        case 14: _t->sigStorageDeviceChange((*reinterpret_cast< std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
+        case 14: _t->sigStorageDeviceChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
         case 15: _t->sigUSBControllerChange(); break;
-        case 16: _t->sigUSBDeviceStateChange((*reinterpret_cast< std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
+        case 16: _t->sigUSBDeviceStateChange((*reinterpret_cast<std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
         case 17: _t->sigVRDEChange(); break;
-        case 18: _t->sigRuntimeError((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[3]))); break;
+        case 18: _t->sigRuntimeError((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
         case 19: _t->sigKeyboardLedsChange(); break;
-        case 20: _t->sigKeyboardStateChange((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
+        case 20: _t->sigKeyboardStateChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
         case 21: _t->sigMousePointerShapeChange(); break;
         case 22: _t->sigMouseCapabilityChange(); break;
         case 23: _t->sigCursorPositionChange(); break;
-        case 24: _t->sigMouseStateChange((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
+        case 24: _t->sigMouseStateChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
         case 25: _t->sigHostScreenCountChange(); break;
         case 26: _t->sigHostScreenGeometryChange(); break;
         case 27: _t->sigHostScreenAvailableAreaChange(); break;
-        case 28: _t->sltInstallGuestAdditionsFrom((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 29: _t->sltMountDVDAdHoc((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 30: _t->setKeyboardState((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
-        case 31: _t->setMouseState((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
+        case 28: _t->sltInstallGuestAdditionsFrom((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 29: _t->sltMountDVDAdHoc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 30: _t->setKeyboardState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
+        case 31: _t->setMouseState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
         case 32: _t->closeRuntimeUI(); break;
-        case 33: _t->sltChangeVisualState((*reinterpret_cast< std::add_pointer_t<UIVisualStateType>>(_a[1]))); break;
+        case 33: _t->sltChangeVisualState((*reinterpret_cast<std::add_pointer_t<UIVisualStateType>>(_a[1]))); break;
         case 34: _t->sltHandleAdditionsActualChange(); break;
         case 35: _t->sltHandleAudioAdapterChange(); break;
         case 36: _t->sltHandleRecordingChange(); break;
-        case 37: _t->sltHandleStorageDeviceChange((*reinterpret_cast< std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
+        case 37: _t->sltHandleStorageDeviceChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
         case 38: _t->sltHandleVRDEChange(); break;
         case 39: _t->sltHandleHostScreenCountChange(); break;
         case 40: _t->sltHandleHostScreenGeometryChange(); break;
         case 41: _t->sltHandleHostScreenAvailableAreaChange(); break;
-        case 42: _t->sltHandleGuestMonitorChange((*reinterpret_cast< std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QRect>>(_a[3]))); break;
-        case 43: _t->sltHandleKeyboardLedsChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
-        case 44: _t->sltHidLedsSyncStateChanged((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 45: _t->sltMousePointerShapeChange((*reinterpret_cast< std::add_pointer_t<UIMousePointerShapeData>>(_a[1]))); break;
-        case 46: _t->sltMouseCapabilityChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[5]))); break;
-        case 47: _t->sltCursorPositionChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[3]))); break;
+        case 42: _t->sltHandleGuestMonitorChange((*reinterpret_cast<std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3]))); break;
+        case 43: _t->sltHandleKeyboardLedsChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 44: _t->sltHidLedsSyncStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 45: _t->sltMousePointerShapeChange((*reinterpret_cast<std::add_pointer_t<UIMousePointerShapeData>>(_a[1]))); break;
+        case 46: _t->sltMouseCapabilityChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
+        case 47: _t->sltCursorPositionChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[3]))); break;
         default: ;
         }
     }
