@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'UIMachineLogic.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.2)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -18,7 +18,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'UIMachineLogic.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.9.2. It"
+#error "This file was generated using the moc from 6.10.0. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -49,6 +49,7 @@ template <> constexpr inline auto UIMachineLogic::qt_create_metaobjectdata<qt_me
         "sltChangeVisualStateToScale",
         "sltMachineStateChanged",
         "sltSessionStateChanged",
+        "QUuid",
         "uId",
         "KSessionState",
         "enmState",
@@ -69,6 +70,7 @@ template <> constexpr inline auto UIMachineLogic::qt_create_metaobjectdata<qt_me
         "KGuestMonitorChangedEventType",
         "changeType",
         "uScreenId",
+        "QRect",
         "screenGeo",
         "sltHostScreenCountChange",
         "sltHostScreenGeometryChange",
@@ -167,188 +169,188 @@ template <> constexpr inline auto UIMachineLogic::qt_create_metaobjectdata<qt_me
         QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
         // Slot 'sltSessionStateChanged'
         QtMocHelpers::SlotData<void(const QUuid &, const KSessionState)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
-            { QMetaType::QUuid, 11 }, { 0x80000000 | 12, 13 },
+            { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 },
         }}),
         // Slot 'sltAdditionsStateChanged'
-        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
-        // Slot 'sltMouseCapabilityChanged'
         QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessProtected, QMetaType::Void),
-        // Slot 'sltKeyboardLedsChanged'
+        // Slot 'sltMouseCapabilityChanged'
         QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessProtected, QMetaType::Void),
+        // Slot 'sltKeyboardLedsChanged'
+        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessProtected, QMetaType::Void),
         // Slot 'sltUSBDeviceStateChange'
-        QtMocHelpers::SlotData<void(const CUSBDevice &, bool, const CVirtualBoxErrorInfo &)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
-            { 0x80000000 | 18, 19 }, { QMetaType::Bool, 20 }, { 0x80000000 | 21, 22 },
+        QtMocHelpers::SlotData<void(const CUSBDevice &, bool, const CVirtualBoxErrorInfo &)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
+            { 0x80000000 | 19, 20 }, { QMetaType::Bool, 21 }, { 0x80000000 | 22, 23 },
         }}),
         // Slot 'sltRuntimeError'
-        QtMocHelpers::SlotData<void(bool, const QString &, const QString &)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
-            { QMetaType::Bool, 24 }, { QMetaType::QString, 25 }, { QMetaType::QString, 26 },
+        QtMocHelpers::SlotData<void(bool, const QString &, const QString &)>(24, 2, QMC::AccessProtected, QMetaType::Void, {{
+            { QMetaType::Bool, 25 }, { QMetaType::QString, 26 }, { QMetaType::QString, 27 },
         }}),
         // Slot 'sltGuestMonitorChange'
-        QtMocHelpers::SlotData<void(KGuestMonitorChangedEventType, ulong, QRect)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
-            { 0x80000000 | 28, 29 }, { QMetaType::ULong, 30 }, { QMetaType::QRect, 31 },
+        QtMocHelpers::SlotData<void(KGuestMonitorChangedEventType, ulong, QRect)>(28, 2, QMC::AccessProtected, QMetaType::Void, {{
+            { 0x80000000 | 29, 30 }, { QMetaType::ULong, 31 }, { 0x80000000 | 32, 33 },
         }}),
         // Slot 'sltHostScreenCountChange'
-        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessProtected, QMetaType::Void),
-        // Slot 'sltHostScreenGeometryChange'
-        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessProtected, QMetaType::Void),
-        // Slot 'sltHostScreenAvailableAreaChange'
         QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessProtected, QMetaType::Void),
-        // Slot 'sltHandleHelpRequest'
+        // Slot 'sltHostScreenGeometryChange'
         QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessProtected, QMetaType::Void),
+        // Slot 'sltHostScreenAvailableAreaChange'
+        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessProtected, QMetaType::Void),
+        // Slot 'sltHandleHelpRequest'
+        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessProtected, QMetaType::Void),
         // Slot 'sltHandleMenuPrepare'
-        QtMocHelpers::SlotData<void(int, QMenu *)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Int, 37 }, { 0x80000000 | 38, 39 },
+        QtMocHelpers::SlotData<void(int, QMenu *)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Int, 39 }, { 0x80000000 | 40, 41 },
         }}),
         // Slot 'sltOpenPreferencesDialogDefault'
-        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltClosePreferencesDialog'
-        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltClose'
         QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltOpenSettingsDialogDefault'
+        // Slot 'sltClosePreferencesDialog'
         QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltCloseSettingsDialog'
+        // Slot 'sltClose'
         QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltTakeSnapshot'
+        // Slot 'sltOpenSettingsDialogDefault'
         QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltShowInformationDialog'
+        // Slot 'sltCloseSettingsDialog'
         QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltCloseInformationDialog'
+        // Slot 'sltTakeSnapshot'
         QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltShowFileManagerDialog'
+        // Slot 'sltShowInformationDialog'
         QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltCloseFileManagerDialog'
+        // Slot 'sltCloseInformationDialog'
         QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltShowLogDialog'
+        // Slot 'sltShowFileManagerDialog'
         QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltCloseLogDialog'
+        // Slot 'sltCloseFileManagerDialog'
         QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltShowLogDialog'
+        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltCloseLogDialog'
+        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltPause'
-        QtMocHelpers::SlotData<void(bool)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 53 },
+        QtMocHelpers::SlotData<void(bool)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 55 },
         }}),
         // Slot 'sltReset'
-        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltDetach'
-        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltSaveState'
         QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltShutdown'
+        // Slot 'sltDetach'
         QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPowerOff'
+        // Slot 'sltSaveState'
         QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltMinimizeActiveMachineWindow'
+        // Slot 'sltShutdown'
         QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltAdjustMachineWindows'
+        // Slot 'sltPowerOff'
         QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltMinimizeActiveMachineWindow'
+        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltAdjustMachineWindows'
+        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltToggleGuestAutoresize'
-        QtMocHelpers::SlotData<void(bool)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 62 },
+        QtMocHelpers::SlotData<void(bool)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 64 },
         }}),
         // Slot 'sltTakeScreenshot'
-        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltOpenRecordingOptions'
-        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltToggleRecording'
-        QtMocHelpers::SlotData<void(bool)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 62 },
+        QtMocHelpers::SlotData<void(bool)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 64 },
         }}),
         // Slot 'sltToggleVRDE'
-        QtMocHelpers::SlotData<void(bool)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 62 },
+        QtMocHelpers::SlotData<void(bool)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 64 },
         }}),
         // Slot 'sltShowKeyboardSettings'
-        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltShowSoftKeyboard'
-        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltCloseSoftKeyboard'
         QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltTypeCAD'
+        // Slot 'sltShowSoftKeyboard'
         QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltTypeCABS'
+        // Slot 'sltCloseSoftKeyboard'
         QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltTypeCtrlBreak'
+        // Slot 'sltTypeCAD'
         QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltTypeInsert'
+        // Slot 'sltTypeCABS'
         QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltTypePrintScreen'
+        // Slot 'sltTypeCtrlBreak'
         QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltTypeAltPrintScreen'
+        // Slot 'sltTypeInsert'
         QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltTypePrintScreen'
+        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltTypeAltPrintScreen'
+        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltTypeHostKeyComboPressRelease'
-        QtMocHelpers::SlotData<void(bool)>(76, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 77 },
+        QtMocHelpers::SlotData<void(bool)>(78, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 79 },
         }}),
         // Slot 'sltToggleMouseIntegration'
-        QtMocHelpers::SlotData<void(bool)>(78, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 62 },
+        QtMocHelpers::SlotData<void(bool)>(80, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 64 },
         }}),
         // Slot 'sltOpenSettingsDialogStorage'
-        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltMountStorageMedium'
-        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltToggleAudioOutput'
-        QtMocHelpers::SlotData<void(bool)>(81, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 62 },
+        QtMocHelpers::SlotData<void(bool)>(83, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 64 },
         }}),
         // Slot 'sltToggleAudioInput'
-        QtMocHelpers::SlotData<void(bool)>(82, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 62 },
+        QtMocHelpers::SlotData<void(bool)>(84, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 64 },
         }}),
         // Slot 'sltOpenSettingsDialogNetwork'
-        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltOpenSettingsDialogUSBDevices'
-        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltOpenSettingsDialogSharedFolders'
         QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltAttachUSBDevice'
+        // Slot 'sltOpenSettingsDialogUSBDevices'
         QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltAttachWebcamDevice'
+        // Slot 'sltOpenSettingsDialogSharedFolders'
         QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltAttachUSBDevice'
+        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltAttachWebcamDevice'
+        QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltChangeSharedClipboardType'
-        QtMocHelpers::SlotData<void(QAction *)>(88, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 89, 90 },
+        QtMocHelpers::SlotData<void(QAction *)>(90, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 91, 92 },
         }}),
         // Slot 'sltFileTransferToggled'
-        QtMocHelpers::SlotData<void(bool)>(91, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 92 },
+        QtMocHelpers::SlotData<void(bool)>(93, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 94 },
         }}),
         // Slot 'sltToggleNetworkAdapterConnection'
-        QtMocHelpers::SlotData<void(bool)>(93, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 92 },
+        QtMocHelpers::SlotData<void(bool)>(95, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 94 },
         }}),
         // Slot 'sltChangeDragAndDropType'
-        QtMocHelpers::SlotData<void(QAction *)>(94, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 89, 90 },
+        QtMocHelpers::SlotData<void(QAction *)>(96, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 91, 92 },
         }}),
         // Slot 'sltInstallGuestAdditions'
-        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltShowDebugStatistics'
-        QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltShowDebugCommandLine'
         QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltShowDebugStatistics'
+        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltShowDebugCommandLine'
+        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltLoggingToggled'
-        QtMocHelpers::SlotData<void(bool)>(98, 2, QMC::AccessPrivate, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(bool)>(100, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
         // Slot 'sltShowGuestControlConsoleDialog'
-        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltCloseGuestControlConsoleDialog'
-        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltSwitchKeyboardLedsToGuestLeds'
         QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltSwitchKeyboardLedsToPreviousLeds'
+        // Slot 'sltCloseGuestControlConsoleDialog'
         QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltSwitchKeyboardLedsToGuestLeds'
+        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltSwitchKeyboardLedsToPreviousLeds'
+        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltDisableHostScreenSaverStateChanged'
-        QtMocHelpers::SlotData<void(bool)>(103, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 104 },
+        QtMocHelpers::SlotData<void(bool)>(105, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 106 },
         }}),
         // Slot 'sltHandleVisualStateChange'
-        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltHandleCommitData'
-        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltRetranslateUI'
         QtMocHelpers::SlotData<void()>(107, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltHandleCommitData'
+        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltRetranslateUI'
+        QtMocHelpers::SlotData<void()>(109, 2, QMC::AccessPrivate, QMetaType::Void),
     };
     QtMocHelpers::UintData qt_properties {
     };
@@ -380,18 +382,18 @@ void UIMachineLogic::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _
         case 5: _t->sltChangeVisualStateToSeamless(); break;
         case 6: _t->sltChangeVisualStateToScale(); break;
         case 7: _t->sltMachineStateChanged(); break;
-        case 8: _t->sltSessionStateChanged((*reinterpret_cast< std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<KSessionState>>(_a[2]))); break;
+        case 8: _t->sltSessionStateChanged((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KSessionState>>(_a[2]))); break;
         case 9: _t->sltAdditionsStateChanged(); break;
         case 10: _t->sltMouseCapabilityChanged(); break;
         case 11: _t->sltKeyboardLedsChanged(); break;
-        case 12: _t->sltUSBDeviceStateChange((*reinterpret_cast< std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
-        case 13: _t->sltRuntimeError((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[3]))); break;
-        case 14: _t->sltGuestMonitorChange((*reinterpret_cast< std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QRect>>(_a[3]))); break;
+        case 12: _t->sltUSBDeviceStateChange((*reinterpret_cast<std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
+        case 13: _t->sltRuntimeError((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
+        case 14: _t->sltGuestMonitorChange((*reinterpret_cast<std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3]))); break;
         case 15: _t->sltHostScreenCountChange(); break;
         case 16: _t->sltHostScreenGeometryChange(); break;
         case 17: _t->sltHostScreenAvailableAreaChange(); break;
         case 18: _t->sltHandleHelpRequest(); break;
-        case 19: _t->sltHandleMenuPrepare((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QMenu*>>(_a[2]))); break;
+        case 19: _t->sltHandleMenuPrepare((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2]))); break;
         case 20: _t->sltOpenPreferencesDialogDefault(); break;
         case 21: _t->sltClosePreferencesDialog(); break;
         case 22: _t->sltClose(); break;
@@ -404,7 +406,7 @@ void UIMachineLogic::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _
         case 29: _t->sltCloseFileManagerDialog(); break;
         case 30: _t->sltShowLogDialog(); break;
         case 31: _t->sltCloseLogDialog(); break;
-        case 32: _t->sltPause((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 32: _t->sltPause((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 33: _t->sltReset(); break;
         case 34: _t->sltDetach(); break;
         case 35: _t->sltSaveState(); break;
@@ -412,11 +414,11 @@ void UIMachineLogic::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _
         case 37: _t->sltPowerOff(); break;
         case 38: _t->sltMinimizeActiveMachineWindow(); break;
         case 39: _t->sltAdjustMachineWindows(); break;
-        case 40: _t->sltToggleGuestAutoresize((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 40: _t->sltToggleGuestAutoresize((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 41: _t->sltTakeScreenshot(); break;
         case 42: _t->sltOpenRecordingOptions(); break;
-        case 43: _t->sltToggleRecording((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 44: _t->sltToggleVRDE((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 43: _t->sltToggleRecording((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 44: _t->sltToggleVRDE((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 45: _t->sltShowKeyboardSettings(); break;
         case 46: _t->sltShowSoftKeyboard(); break;
         case 47: _t->sltCloseSoftKeyboard(); break;
@@ -426,30 +428,30 @@ void UIMachineLogic::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _
         case 51: _t->sltTypeInsert(); break;
         case 52: _t->sltTypePrintScreen(); break;
         case 53: _t->sltTypeAltPrintScreen(); break;
-        case 54: _t->sltTypeHostKeyComboPressRelease((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 55: _t->sltToggleMouseIntegration((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 54: _t->sltTypeHostKeyComboPressRelease((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 55: _t->sltToggleMouseIntegration((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 56: _t->sltOpenSettingsDialogStorage(); break;
         case 57: _t->sltMountStorageMedium(); break;
-        case 58: _t->sltToggleAudioOutput((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 59: _t->sltToggleAudioInput((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 58: _t->sltToggleAudioOutput((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 59: _t->sltToggleAudioInput((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 60: _t->sltOpenSettingsDialogNetwork(); break;
         case 61: _t->sltOpenSettingsDialogUSBDevices(); break;
         case 62: _t->sltOpenSettingsDialogSharedFolders(); break;
         case 63: _t->sltAttachUSBDevice(); break;
         case 64: _t->sltAttachWebcamDevice(); break;
-        case 65: _t->sltChangeSharedClipboardType((*reinterpret_cast< std::add_pointer_t<QAction*>>(_a[1]))); break;
-        case 66: _t->sltFileTransferToggled((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 67: _t->sltToggleNetworkAdapterConnection((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 68: _t->sltChangeDragAndDropType((*reinterpret_cast< std::add_pointer_t<QAction*>>(_a[1]))); break;
+        case 65: _t->sltChangeSharedClipboardType((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
+        case 66: _t->sltFileTransferToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 67: _t->sltToggleNetworkAdapterConnection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 68: _t->sltChangeDragAndDropType((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
         case 69: _t->sltInstallGuestAdditions(); break;
         case 70: _t->sltShowDebugStatistics(); break;
         case 71: _t->sltShowDebugCommandLine(); break;
-        case 72: _t->sltLoggingToggled((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 72: _t->sltLoggingToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 73: _t->sltShowGuestControlConsoleDialog(); break;
         case 74: _t->sltCloseGuestControlConsoleDialog(); break;
         case 75: _t->sltSwitchKeyboardLedsToGuestLeds(); break;
         case 76: _t->sltSwitchKeyboardLedsToPreviousLeds(); break;
-        case 77: _t->sltDisableHostScreenSaverStateChanged((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 77: _t->sltDisableHostScreenSaverStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 78: _t->sltHandleVisualStateChange(); break;
         case 79: _t->sltHandleCommitData(); break;
         case 80: _t->sltRetranslateUI(); break;
