@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'UISession.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.2)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -18,7 +18,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'UISession.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.9.2. It"
+#error "This file was generated using the moc from 6.10.0. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -53,6 +53,7 @@ template <> constexpr inline auto UISession::qt_create_metaobjectdata<qt_meta_ta
         "KGuestMonitorChangedEventType",
         "enmChangeType",
         "uScreenId",
+        "QRect",
         "screenGeo",
         "sigMachineStateChange",
         "sigMediumChange",
@@ -132,86 +133,86 @@ template <> constexpr inline auto UISession::qt_create_metaobjectdata<qt_meta_ta
         }}),
         // Signal 'sigGuestMonitorChange'
         QtMocHelpers::SignalData<void(KGuestMonitorChangedEventType, ulong, QRect)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 12, 13 }, { QMetaType::ULong, 14 }, { QMetaType::QRect, 15 },
+            { 0x80000000 | 12, 13 }, { QMetaType::ULong, 14 }, { 0x80000000 | 15, 16 },
         }}),
         // Signal 'sigMachineStateChange'
-        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigMediumChange'
-        QtMocHelpers::SignalData<void(const CMediumAttachment &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 18, 19 },
+        QtMocHelpers::SignalData<void(const CMediumAttachment &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 19, 20 },
         }}),
         // Signal 'sigNetworkAdapterChange'
-        QtMocHelpers::SignalData<void(const CNetworkAdapter &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 21, 22 },
+        QtMocHelpers::SignalData<void(const CNetworkAdapter &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 22, 23 },
         }}),
         // Signal 'sigRecordingChange'
-        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
-        // Signal 'sigSharedFolderChange'
         QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
+        // Signal 'sigSharedFolderChange'
+        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigStorageDeviceChange'
-        QtMocHelpers::SignalData<void(const CMediumAttachment &, bool, bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 18, 26 }, { QMetaType::Bool, 27 }, { QMetaType::Bool, 28 },
+        QtMocHelpers::SignalData<void(const CMediumAttachment &, bool, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 19, 27 }, { QMetaType::Bool, 28 }, { QMetaType::Bool, 29 },
         }}),
         // Signal 'sigUSBControllerChange'
-        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigUSBDeviceStateChange'
-        QtMocHelpers::SignalData<void(const CUSBDevice &, bool, const CVirtualBoxErrorInfo &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 31, 32 }, { QMetaType::Bool, 33 }, { 0x80000000 | 34, 35 },
+        QtMocHelpers::SignalData<void(const CUSBDevice &, bool, const CVirtualBoxErrorInfo &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 32, 33 }, { QMetaType::Bool, 34 }, { 0x80000000 | 35, 36 },
         }}),
         // Signal 'sigVRDEChange'
-        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SignalData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'sigRuntimeError'
-        QtMocHelpers::SignalData<void(bool, const QString &, const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 38 }, { QMetaType::QString, 39 }, { QMetaType::QString, 40 },
+        QtMocHelpers::SignalData<void(bool, const QString &, const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 39 }, { QMetaType::QString, 40 }, { QMetaType::QString, 41 },
         }}),
         // Signal 'sigKeyboardLedsChange'
-        QtMocHelpers::SignalData<void(bool, bool, bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 42 }, { QMetaType::Bool, 43 }, { QMetaType::Bool, 44 },
+        QtMocHelpers::SignalData<void(bool, bool, bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 43 }, { QMetaType::Bool, 44 }, { QMetaType::Bool, 45 },
         }}),
         // Signal 'sigMousePointerShapeChange'
-        QtMocHelpers::SignalData<void(const UIMousePointerShapeData &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 46, 47 },
+        QtMocHelpers::SignalData<void(const UIMousePointerShapeData &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 47, 48 },
         }}),
         // Signal 'sigMouseCapabilityChange'
-        QtMocHelpers::SignalData<void(bool, bool, bool, bool, bool)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 49 }, { QMetaType::Bool, 50 }, { QMetaType::Bool, 51 }, { QMetaType::Bool, 52 },
-            { QMetaType::Bool, 53 },
+        QtMocHelpers::SignalData<void(bool, bool, bool, bool, bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 50 }, { QMetaType::Bool, 51 }, { QMetaType::Bool, 52 }, { QMetaType::Bool, 53 },
+            { QMetaType::Bool, 54 },
         }}),
         // Signal 'sigCursorPositionChange'
-        QtMocHelpers::SignalData<void(bool, unsigned long, unsigned long)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 55 }, { QMetaType::ULong, 56 }, { QMetaType::ULong, 57 },
+        QtMocHelpers::SignalData<void(bool, unsigned long, unsigned long)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 56 }, { QMetaType::ULong, 57 }, { QMetaType::ULong, 58 },
         }}),
         // Slot 'sltInstallGuestAdditionsFrom'
-        QtMocHelpers::SlotData<void(const QString &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 59 },
+        QtMocHelpers::SlotData<void(const QString &)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 60 },
         }}),
         // Slot 'sltMountDVDAdHoc'
-        QtMocHelpers::SlotData<void(const QString &)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 59 },
+        QtMocHelpers::SlotData<void(const QString &)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 60 },
         }}),
         // Slot 'sltDetachCOM'
-        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltStateChange'
-        QtMocHelpers::SlotData<void(KMachineState)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { 0x80000000 | 63, 64 },
+        QtMocHelpers::SlotData<void(KMachineState)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 64, 65 },
         }}),
         // Slot 'sltAdditionsChange'
-        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltClipboardError'
-        QtMocHelpers::SlotData<void(const QString &)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QString, 67 },
+        QtMocHelpers::SlotData<void(const QString &)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::QString, 68 },
         }}),
         // Slot 'sltHandleMachineStateSaved'
-        QtMocHelpers::SlotData<void(bool)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 69 },
+        QtMocHelpers::SlotData<void(bool)>(69, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 70 },
         }}),
         // Slot 'sltHandleMachinePoweredOff'
-        QtMocHelpers::SlotData<void(bool, bool)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 69 }, { QMetaType::Bool, 71 },
+        QtMocHelpers::SlotData<void(bool, bool)>(71, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 70 }, { QMetaType::Bool, 72 },
         }}),
         // Slot 'sltHandleSnapshotRestored'
-        QtMocHelpers::SlotData<void(bool)>(72, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 69 },
+        QtMocHelpers::SlotData<void(bool)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 70 },
         }}),
     };
     QtMocHelpers::UintData qt_properties {
@@ -239,33 +240,33 @@ void UISession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, v
         case 0: _t->sigAdditionsStateChange(); break;
         case 1: _t->sigAdditionsStateActualChange(); break;
         case 2: _t->sigAudioAdapterChange(); break;
-        case 3: _t->sigClipboardModeChange((*reinterpret_cast< std::add_pointer_t<KClipboardMode>>(_a[1]))); break;
+        case 3: _t->sigClipboardModeChange((*reinterpret_cast<std::add_pointer_t<KClipboardMode>>(_a[1]))); break;
         case 4: _t->sigCPUExecutionCapChange(); break;
-        case 5: _t->sigDnDModeChange((*reinterpret_cast< std::add_pointer_t<KDnDMode>>(_a[1]))); break;
-        case 6: _t->sigGuestMonitorChange((*reinterpret_cast< std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QRect>>(_a[3]))); break;
+        case 5: _t->sigDnDModeChange((*reinterpret_cast<std::add_pointer_t<KDnDMode>>(_a[1]))); break;
+        case 6: _t->sigGuestMonitorChange((*reinterpret_cast<std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3]))); break;
         case 7: _t->sigMachineStateChange(); break;
-        case 8: _t->sigMediumChange((*reinterpret_cast< std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
-        case 9: _t->sigNetworkAdapterChange((*reinterpret_cast< std::add_pointer_t<CNetworkAdapter>>(_a[1]))); break;
+        case 8: _t->sigMediumChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
+        case 9: _t->sigNetworkAdapterChange((*reinterpret_cast<std::add_pointer_t<CNetworkAdapter>>(_a[1]))); break;
         case 10: _t->sigRecordingChange(); break;
         case 11: _t->sigSharedFolderChange(); break;
-        case 12: _t->sigStorageDeviceChange((*reinterpret_cast< std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
+        case 12: _t->sigStorageDeviceChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
         case 13: _t->sigUSBControllerChange(); break;
-        case 14: _t->sigUSBDeviceStateChange((*reinterpret_cast< std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
+        case 14: _t->sigUSBDeviceStateChange((*reinterpret_cast<std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
         case 15: _t->sigVRDEChange(); break;
-        case 16: _t->sigRuntimeError((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[3]))); break;
-        case 17: _t->sigKeyboardLedsChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
-        case 18: _t->sigMousePointerShapeChange((*reinterpret_cast< std::add_pointer_t<UIMousePointerShapeData>>(_a[1]))); break;
-        case 19: _t->sigMouseCapabilityChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[5]))); break;
-        case 20: _t->sigCursorPositionChange((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<ulong>>(_a[3]))); break;
-        case 21: _t->sltInstallGuestAdditionsFrom((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 22: _t->sltMountDVDAdHoc((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
+        case 16: _t->sigRuntimeError((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
+        case 17: _t->sigKeyboardLedsChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 18: _t->sigMousePointerShapeChange((*reinterpret_cast<std::add_pointer_t<UIMousePointerShapeData>>(_a[1]))); break;
+        case 19: _t->sigMouseCapabilityChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
+        case 20: _t->sigCursorPositionChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[3]))); break;
+        case 21: _t->sltInstallGuestAdditionsFrom((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 22: _t->sltMountDVDAdHoc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
         case 23: _t->sltDetachCOM(); break;
-        case 24: _t->sltStateChange((*reinterpret_cast< std::add_pointer_t<KMachineState>>(_a[1]))); break;
+        case 24: _t->sltStateChange((*reinterpret_cast<std::add_pointer_t<KMachineState>>(_a[1]))); break;
         case 25: _t->sltAdditionsChange(); break;
-        case 26: _t->sltClipboardError((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 27: _t->sltHandleMachineStateSaved((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 28: _t->sltHandleMachinePoweredOff((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2]))); break;
-        case 29: _t->sltHandleSnapshotRestored((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 26: _t->sltClipboardError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 27: _t->sltHandleMachineStateSaved((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 28: _t->sltHandleMachinePoweredOff((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
+        case 29: _t->sltHandleSnapshotRestored((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         default: ;
         }
     }
